"""
   /*
   **   Generated by blitz/resources/templates/combined.vm
   **
   **   Copyright 2007, 2008 Glencoe Software, Inc. All rights reserved.
   **   Use is subject to license terms supplied in LICENSE.txt
   **
   */
"""
try:
   unicode
except NameError:
   # Python 3: "unicode" is built-in
   unicode = str
import Ice
import IceImport
import omero
IceImport.load("omero_model_DetailsI")
IceImport.load("omero_model_Instrument_ice")
from omero.rtypes import rlong
from collections import namedtuple
_omero = Ice.openModule("omero")
_omero_model = Ice.openModule("omero.model")
__name__ = "omero.model"
class InstrumentI(_omero_model.Instrument):

      # Property Metadata
      _field_info_data = namedtuple("FieldData", ["wrapper", "nullable"])
      _field_info_type = namedtuple("FieldInfo", [
          "microscope",
          "detector",
          "objective",
          "lightSource",
          "filter",
          "dichroic",
          "filterSet",
          "otf",
          "annotationLinks",
          "details",
      ])
      _field_info = _field_info_type(
          microscope=_field_info_data(wrapper=omero.proxy_to_instance, nullable=True),
          detector=_field_info_data(wrapper=omero.proxy_to_instance, nullable=True),
          objective=_field_info_data(wrapper=omero.proxy_to_instance, nullable=True),
          lightSource=_field_info_data(wrapper=omero.proxy_to_instance, nullable=True),
          filter=_field_info_data(wrapper=omero.proxy_to_instance, nullable=True),
          dichroic=_field_info_data(wrapper=omero.proxy_to_instance, nullable=True),
          filterSet=_field_info_data(wrapper=omero.proxy_to_instance, nullable=True),
          otf=_field_info_data(wrapper=omero.proxy_to_instance, nullable=True),
          annotationLinks=_field_info_data(wrapper=omero.proxy_to_instance, nullable=True),
          details=_field_info_data(wrapper=omero.proxy_to_instance, nullable=True),
      )  # end _field_info
      MICROSCOPE =  "ome.model.acquisition.Instrument_microscope"
      DETECTOR =  "ome.model.acquisition.Instrument_detector"
      OBJECTIVE =  "ome.model.acquisition.Instrument_objective"
      LIGHTSOURCE =  "ome.model.acquisition.Instrument_lightSource"
      FILTER =  "ome.model.acquisition.Instrument_filter"
      DICHROIC =  "ome.model.acquisition.Instrument_dichroic"
      FILTERSET =  "ome.model.acquisition.Instrument_filterSet"
      OTF =  "ome.model.acquisition.Instrument_otf"
      ANNOTATIONLINKS =  "ome.model.acquisition.Instrument_annotationLinks"
      DETAILS =  "ome.model.acquisition.Instrument_details"
      def errorIfUnloaded(self):
          if not self._loaded:
              raise _omero.UnloadedEntityException("Object unloaded:"+str(self))

      def throwNullCollectionException(self,propertyName):
          raise _omero.UnloadedEntityException(""+
          "Error updating collection:" + propertyName +"\n"+
          "Collection is currently null. This can be seen\n" +
          "by testing \""+ propertyName +"Loaded\". This implies\n"+
          "that this collection was unloaded. Please refresh this object\n"+
          "in order to update this collection.\n")

      def _toggleCollectionsLoaded(self, load):
          if load:
              self._detectorSeq = []
              self._detectorLoaded = True;
          else:
              self._detectorSeq = []
              self._detectorLoaded = False;

          if load:
              self._objectiveSeq = []
              self._objectiveLoaded = True;
          else:
              self._objectiveSeq = []
              self._objectiveLoaded = False;

          if load:
              self._lightSourceSeq = []
              self._lightSourceLoaded = True;
          else:
              self._lightSourceSeq = []
              self._lightSourceLoaded = False;

          if load:
              self._filterSeq = []
              self._filterLoaded = True;
          else:
              self._filterSeq = []
              self._filterLoaded = False;

          if load:
              self._dichroicSeq = []
              self._dichroicLoaded = True;
          else:
              self._dichroicSeq = []
              self._dichroicLoaded = False;

          if load:
              self._filterSetSeq = []
              self._filterSetLoaded = True;
          else:
              self._filterSetSeq = []
              self._filterSetLoaded = False;

          if load:
              self._otfSeq = []
              self._otfLoaded = True;
          else:
              self._otfSeq = []
              self._otfLoaded = False;

          if load:
              self._annotationLinksSeq = []
              self._annotationLinksLoaded = True;
          else:
              self._annotationLinksSeq = []
              self._annotationLinksLoaded = False;

          pass

      def __init__(self, id=None, loaded=None):
          super(InstrumentI, self).__init__()
          if id is not None and isinstance(id, (str, unicode)) and ":" in id:
              parts = id.split(":")
              if len(parts) != 2:
                  raise Exception("Invalid proxy string: %s", id)
              if parts[0] != self.__class__.__name__ and \
                 parts[0]+"I" != self.__class__.__name__:
                  raise Exception("Proxy class mismatch: %s<>%s" %
                  (self.__class__.__name__, parts[0]))
              self._id = rlong(parts[1])
              if loaded is None:
                  # If no loadedness was requested with
                  # a proxy string, then assume False.
                  loaded = False
          else:
              # Relying on omero.rtypes.rlong's error-handling
              self._id = rlong(id)
              if loaded is None:
                  loaded = True  # Assume true as previously
          self._loaded = loaded
          if self._loaded:
             self._details = _omero_model.DetailsI()
             self._toggleCollectionsLoaded(True)

      def unload(self, current = None):
          self._loaded = False
          self.unloadMicroscope( )
          self.unloadDetector( )
          self.unloadObjective( )
          self.unloadLightSource( )
          self.unloadFilter( )
          self.unloadDichroic( )
          self.unloadFilterSet( )
          self.unloadOtf( )
          self.unloadAnnotationLinks( )
          self.unloadDetails( )

      def isLoaded(self, current = None):
          return self._loaded
      def unloadCollections(self, current = None):
          self._toggleCollectionsLoaded( False )
      def isGlobal(self, current = None):
          return  False ;
      def isMutable(self, current = None):
          return  True ;
      def isAnnotated(self, current = None):
          return  True ;
      def isLink(self, current = None):
          return  False ;
      def shallowCopy(self, current = None):
            if not self._loaded: return self.proxy()
            copy = InstrumentI()
            copy._id = self._id;
            copy._version = self._version;
            copy._details = None  # Unloading for the moment.
            raise omero.ClientError("NYI")
      def proxy(self, current = None):
          if self._id is None: raise omero.ClientError("Proxies require an id")
          return InstrumentI( self._id.getValue(), False )

      def getDetails(self, current = None):
          self.errorIfUnloaded()
          return self._details

      def unloadDetails(self, current = None):
          self._details = None

      def getId(self, current = None):
          return self._id

      def setId(self, _id, current = None):
          self._id = _id

      def checkUnloadedProperty(self, value, loadedField):
          if value == None:
              self.__dict__[loadedField] = False
          else:
              self.__dict__[loadedField] = True

      def getVersion(self, current = None):
          self.errorIfUnloaded()
          return self._version

      def setVersion(self, version, current = None):
          self.errorIfUnloaded()
          self._version = version

      def unloadMicroscope(self, ):
          self._microscopeLoaded = False
          self._microscope = None;

      def getMicroscope(self, current = None):
          self.errorIfUnloaded()
          return self._microscope

      def setMicroscope(self, _microscope, current = None, wrap=False):
          self.errorIfUnloaded()
          if wrap and self._field_info.microscope.wrapper is not None:
              if _microscope is not None:
                  _microscope = self._field_info.microscope.wrapper(_microscope)
          self._microscope = _microscope
          pass

      def unloadDetector(self, current = None):
          self._detectorLoaded = False
          self._detectorSeq = None;

      def _getDetector(self, current = None):
          self.errorIfUnloaded()
          return self._detectorSeq

      def _setDetector(self, _detector, current = None, wrap=False):
          self.errorIfUnloaded()
          if wrap and self._field_info.detectorSeq.wrapper is not None:
              if _detector is not None:
                  _detector = self._field_info.detectorSeq.wrapper(_detector)
          self._detectorSeq = _detector
          self.checkUnloadedProperty(_detector,'detectorLoaded')

      def isDetectorLoaded(self):
          return self._detectorLoaded

      def sizeOfDetector(self, current = None):
          self.errorIfUnloaded()
          if not self._detectorLoaded: return -1
          return len(self._detectorSeq)

      def copyDetector(self, current = None):
          self.errorIfUnloaded()
          if not self._detectorLoaded: self.throwNullCollectionException("detectorSeq")
          return list(self._detectorSeq)

      def iterateDetector(self):
          self.errorIfUnloaded()
          if not self._detectorLoaded: self.throwNullCollectionException("detectorSeq")
          return iter(self._detectorSeq)

      def addDetector(self, target, current = None):
          self.errorIfUnloaded()
          if not self._detectorLoaded: self.throwNullCollectionException("detectorSeq")
          self._detectorSeq.append( target );
          target.setInstrument( self )

      def addAllDetectorSet(self, targets, current = None):
          self.errorIfUnloaded()
          if  not self._detectorLoaded: self.throwNullCollectionException("detectorSeq")
          self._detectorSeq.extend( targets )
          for target in targets:
              target.setInstrument( self )

      def removeDetector(self, target, current = None):
          self.errorIfUnloaded()
          if not self._detectorLoaded: self.throwNullCollectionException("detectorSeq")
          self._detectorSeq.remove( target )
          target.setInstrument( None )

      def removeAllDetectorSet(self, targets, current = None):
          self.errorIfUnloaded()
          if not self._detectorLoaded: self.throwNullCollectionException("detectorSeq")
          for elt in targets:
              elt.setInstrument( None )
              self._detectorSeq.remove( elt )

      def clearDetector(self, current = None):
          self.errorIfUnloaded()
          if not self._detectorLoaded: self.throwNullCollectionException("detectorSeq")
          for elt in self._detectorSeq:
              elt.setInstrument( None )
          self._detectorSeq = list()

      def reloadDetector(self, toCopy, current = None):
          self.errorIfUnloaded()
          if self._detectorLoaded:
              raise omero.ClientError("Cannot reload active collection: detectorSeq")
          if not toCopy:
              raise omero.ClientError("Argument cannot be null")
          if toCopy.getId().getValue() != self.getId().getValue():
             raise omero.ClientError("Argument must have the same id as this instance")
          if toCopy.getDetails().getUpdateEvent().getId().getValue() < self.getDetails().getUpdateEvent().getId().getValue():
             raise omero.ClientError("Argument may not be older than this instance")
          copy = toCopy.copyDetector() # May also throw
          for elt in copy:
              elt.setInstrument( self )
          self._detectorSeq = copy
          toCopy.unloadDetector()
          self._detectorLoaded = True

      def unloadObjective(self, current = None):
          self._objectiveLoaded = False
          self._objectiveSeq = None;

      def _getObjective(self, current = None):
          self.errorIfUnloaded()
          return self._objectiveSeq

      def _setObjective(self, _objective, current = None, wrap=False):
          self.errorIfUnloaded()
          if wrap and self._field_info.objectiveSeq.wrapper is not None:
              if _objective is not None:
                  _objective = self._field_info.objectiveSeq.wrapper(_objective)
          self._objectiveSeq = _objective
          self.checkUnloadedProperty(_objective,'objectiveLoaded')

      def isObjectiveLoaded(self):
          return self._objectiveLoaded

      def sizeOfObjective(self, current = None):
          self.errorIfUnloaded()
          if not self._objectiveLoaded: return -1
          return len(self._objectiveSeq)

      def copyObjective(self, current = None):
          self.errorIfUnloaded()
          if not self._objectiveLoaded: self.throwNullCollectionException("objectiveSeq")
          return list(self._objectiveSeq)

      def iterateObjective(self):
          self.errorIfUnloaded()
          if not self._objectiveLoaded: self.throwNullCollectionException("objectiveSeq")
          return iter(self._objectiveSeq)

      def addObjective(self, target, current = None):
          self.errorIfUnloaded()
          if not self._objectiveLoaded: self.throwNullCollectionException("objectiveSeq")
          self._objectiveSeq.append( target );
          target.setInstrument( self )

      def addAllObjectiveSet(self, targets, current = None):
          self.errorIfUnloaded()
          if  not self._objectiveLoaded: self.throwNullCollectionException("objectiveSeq")
          self._objectiveSeq.extend( targets )
          for target in targets:
              target.setInstrument( self )

      def removeObjective(self, target, current = None):
          self.errorIfUnloaded()
          if not self._objectiveLoaded: self.throwNullCollectionException("objectiveSeq")
          self._objectiveSeq.remove( target )
          target.setInstrument( None )

      def removeAllObjectiveSet(self, targets, current = None):
          self.errorIfUnloaded()
          if not self._objectiveLoaded: self.throwNullCollectionException("objectiveSeq")
          for elt in targets:
              elt.setInstrument( None )
              self._objectiveSeq.remove( elt )

      def clearObjective(self, current = None):
          self.errorIfUnloaded()
          if not self._objectiveLoaded: self.throwNullCollectionException("objectiveSeq")
          for elt in self._objectiveSeq:
              elt.setInstrument( None )
          self._objectiveSeq = list()

      def reloadObjective(self, toCopy, current = None):
          self.errorIfUnloaded()
          if self._objectiveLoaded:
              raise omero.ClientError("Cannot reload active collection: objectiveSeq")
          if not toCopy:
              raise omero.ClientError("Argument cannot be null")
          if toCopy.getId().getValue() != self.getId().getValue():
             raise omero.ClientError("Argument must have the same id as this instance")
          if toCopy.getDetails().getUpdateEvent().getId().getValue() < self.getDetails().getUpdateEvent().getId().getValue():
             raise omero.ClientError("Argument may not be older than this instance")
          copy = toCopy.copyObjective() # May also throw
          for elt in copy:
              elt.setInstrument( self )
          self._objectiveSeq = copy
          toCopy.unloadObjective()
          self._objectiveLoaded = True

      def unloadLightSource(self, current = None):
          self._lightSourceLoaded = False
          self._lightSourceSeq = None;

      def _getLightSource(self, current = None):
          self.errorIfUnloaded()
          return self._lightSourceSeq

      def _setLightSource(self, _lightSource, current = None, wrap=False):
          self.errorIfUnloaded()
          if wrap and self._field_info.lightSourceSeq.wrapper is not None:
              if _lightSource is not None:
                  _lightSource = self._field_info.lightSourceSeq.wrapper(_lightSource)
          self._lightSourceSeq = _lightSource
          self.checkUnloadedProperty(_lightSource,'lightSourceLoaded')

      def isLightSourceLoaded(self):
          return self._lightSourceLoaded

      def sizeOfLightSource(self, current = None):
          self.errorIfUnloaded()
          if not self._lightSourceLoaded: return -1
          return len(self._lightSourceSeq)

      def copyLightSource(self, current = None):
          self.errorIfUnloaded()
          if not self._lightSourceLoaded: self.throwNullCollectionException("lightSourceSeq")
          return list(self._lightSourceSeq)

      def iterateLightSource(self):
          self.errorIfUnloaded()
          if not self._lightSourceLoaded: self.throwNullCollectionException("lightSourceSeq")
          return iter(self._lightSourceSeq)

      def addLightSource(self, target, current = None):
          self.errorIfUnloaded()
          if not self._lightSourceLoaded: self.throwNullCollectionException("lightSourceSeq")
          self._lightSourceSeq.append( target );
          target.setInstrument( self )

      def addAllLightSourceSet(self, targets, current = None):
          self.errorIfUnloaded()
          if  not self._lightSourceLoaded: self.throwNullCollectionException("lightSourceSeq")
          self._lightSourceSeq.extend( targets )
          for target in targets:
              target.setInstrument( self )

      def removeLightSource(self, target, current = None):
          self.errorIfUnloaded()
          if not self._lightSourceLoaded: self.throwNullCollectionException("lightSourceSeq")
          self._lightSourceSeq.remove( target )
          target.setInstrument( None )

      def removeAllLightSourceSet(self, targets, current = None):
          self.errorIfUnloaded()
          if not self._lightSourceLoaded: self.throwNullCollectionException("lightSourceSeq")
          for elt in targets:
              elt.setInstrument( None )
              self._lightSourceSeq.remove( elt )

      def clearLightSource(self, current = None):
          self.errorIfUnloaded()
          if not self._lightSourceLoaded: self.throwNullCollectionException("lightSourceSeq")
          for elt in self._lightSourceSeq:
              elt.setInstrument( None )
          self._lightSourceSeq = list()

      def reloadLightSource(self, toCopy, current = None):
          self.errorIfUnloaded()
          if self._lightSourceLoaded:
              raise omero.ClientError("Cannot reload active collection: lightSourceSeq")
          if not toCopy:
              raise omero.ClientError("Argument cannot be null")
          if toCopy.getId().getValue() != self.getId().getValue():
             raise omero.ClientError("Argument must have the same id as this instance")
          if toCopy.getDetails().getUpdateEvent().getId().getValue() < self.getDetails().getUpdateEvent().getId().getValue():
             raise omero.ClientError("Argument may not be older than this instance")
          copy = toCopy.copyLightSource() # May also throw
          for elt in copy:
              elt.setInstrument( self )
          self._lightSourceSeq = copy
          toCopy.unloadLightSource()
          self._lightSourceLoaded = True

      def unloadFilter(self, current = None):
          self._filterLoaded = False
          self._filterSeq = None;

      def _getFilter(self, current = None):
          self.errorIfUnloaded()
          return self._filterSeq

      def _setFilter(self, _filter, current = None, wrap=False):
          self.errorIfUnloaded()
          if wrap and self._field_info.filterSeq.wrapper is not None:
              if _filter is not None:
                  _filter = self._field_info.filterSeq.wrapper(_filter)
          self._filterSeq = _filter
          self.checkUnloadedProperty(_filter,'filterLoaded')

      def isFilterLoaded(self):
          return self._filterLoaded

      def sizeOfFilter(self, current = None):
          self.errorIfUnloaded()
          if not self._filterLoaded: return -1
          return len(self._filterSeq)

      def copyFilter(self, current = None):
          self.errorIfUnloaded()
          if not self._filterLoaded: self.throwNullCollectionException("filterSeq")
          return list(self._filterSeq)

      def iterateFilter(self):
          self.errorIfUnloaded()
          if not self._filterLoaded: self.throwNullCollectionException("filterSeq")
          return iter(self._filterSeq)

      def addFilter(self, target, current = None):
          self.errorIfUnloaded()
          if not self._filterLoaded: self.throwNullCollectionException("filterSeq")
          self._filterSeq.append( target );
          target.setInstrument( self )

      def addAllFilterSet(self, targets, current = None):
          self.errorIfUnloaded()
          if  not self._filterLoaded: self.throwNullCollectionException("filterSeq")
          self._filterSeq.extend( targets )
          for target in targets:
              target.setInstrument( self )

      def removeFilter(self, target, current = None):
          self.errorIfUnloaded()
          if not self._filterLoaded: self.throwNullCollectionException("filterSeq")
          self._filterSeq.remove( target )
          target.setInstrument( None )

      def removeAllFilterSet(self, targets, current = None):
          self.errorIfUnloaded()
          if not self._filterLoaded: self.throwNullCollectionException("filterSeq")
          for elt in targets:
              elt.setInstrument( None )
              self._filterSeq.remove( elt )

      def clearFilter(self, current = None):
          self.errorIfUnloaded()
          if not self._filterLoaded: self.throwNullCollectionException("filterSeq")
          for elt in self._filterSeq:
              elt.setInstrument( None )
          self._filterSeq = list()

      def reloadFilter(self, toCopy, current = None):
          self.errorIfUnloaded()
          if self._filterLoaded:
              raise omero.ClientError("Cannot reload active collection: filterSeq")
          if not toCopy:
              raise omero.ClientError("Argument cannot be null")
          if toCopy.getId().getValue() != self.getId().getValue():
             raise omero.ClientError("Argument must have the same id as this instance")
          if toCopy.getDetails().getUpdateEvent().getId().getValue() < self.getDetails().getUpdateEvent().getId().getValue():
             raise omero.ClientError("Argument may not be older than this instance")
          copy = toCopy.copyFilter() # May also throw
          for elt in copy:
              elt.setInstrument( self )
          self._filterSeq = copy
          toCopy.unloadFilter()
          self._filterLoaded = True

      def unloadDichroic(self, current = None):
          self._dichroicLoaded = False
          self._dichroicSeq = None;

      def _getDichroic(self, current = None):
          self.errorIfUnloaded()
          return self._dichroicSeq

      def _setDichroic(self, _dichroic, current = None, wrap=False):
          self.errorIfUnloaded()
          if wrap and self._field_info.dichroicSeq.wrapper is not None:
              if _dichroic is not None:
                  _dichroic = self._field_info.dichroicSeq.wrapper(_dichroic)
          self._dichroicSeq = _dichroic
          self.checkUnloadedProperty(_dichroic,'dichroicLoaded')

      def isDichroicLoaded(self):
          return self._dichroicLoaded

      def sizeOfDichroic(self, current = None):
          self.errorIfUnloaded()
          if not self._dichroicLoaded: return -1
          return len(self._dichroicSeq)

      def copyDichroic(self, current = None):
          self.errorIfUnloaded()
          if not self._dichroicLoaded: self.throwNullCollectionException("dichroicSeq")
          return list(self._dichroicSeq)

      def iterateDichroic(self):
          self.errorIfUnloaded()
          if not self._dichroicLoaded: self.throwNullCollectionException("dichroicSeq")
          return iter(self._dichroicSeq)

      def addDichroic(self, target, current = None):
          self.errorIfUnloaded()
          if not self._dichroicLoaded: self.throwNullCollectionException("dichroicSeq")
          self._dichroicSeq.append( target );
          target.setInstrument( self )

      def addAllDichroicSet(self, targets, current = None):
          self.errorIfUnloaded()
          if  not self._dichroicLoaded: self.throwNullCollectionException("dichroicSeq")
          self._dichroicSeq.extend( targets )
          for target in targets:
              target.setInstrument( self )

      def removeDichroic(self, target, current = None):
          self.errorIfUnloaded()
          if not self._dichroicLoaded: self.throwNullCollectionException("dichroicSeq")
          self._dichroicSeq.remove( target )
          target.setInstrument( None )

      def removeAllDichroicSet(self, targets, current = None):
          self.errorIfUnloaded()
          if not self._dichroicLoaded: self.throwNullCollectionException("dichroicSeq")
          for elt in targets:
              elt.setInstrument( None )
              self._dichroicSeq.remove( elt )

      def clearDichroic(self, current = None):
          self.errorIfUnloaded()
          if not self._dichroicLoaded: self.throwNullCollectionException("dichroicSeq")
          for elt in self._dichroicSeq:
              elt.setInstrument( None )
          self._dichroicSeq = list()

      def reloadDichroic(self, toCopy, current = None):
          self.errorIfUnloaded()
          if self._dichroicLoaded:
              raise omero.ClientError("Cannot reload active collection: dichroicSeq")
          if not toCopy:
              raise omero.ClientError("Argument cannot be null")
          if toCopy.getId().getValue() != self.getId().getValue():
             raise omero.ClientError("Argument must have the same id as this instance")
          if toCopy.getDetails().getUpdateEvent().getId().getValue() < self.getDetails().getUpdateEvent().getId().getValue():
             raise omero.ClientError("Argument may not be older than this instance")
          copy = toCopy.copyDichroic() # May also throw
          for elt in copy:
              elt.setInstrument( self )
          self._dichroicSeq = copy
          toCopy.unloadDichroic()
          self._dichroicLoaded = True

      def unloadFilterSet(self, current = None):
          self._filterSetLoaded = False
          self._filterSetSeq = None;

      def _getFilterSet(self, current = None):
          self.errorIfUnloaded()
          return self._filterSetSeq

      def _setFilterSet(self, _filterSet, current = None, wrap=False):
          self.errorIfUnloaded()
          if wrap and self._field_info.filterSetSeq.wrapper is not None:
              if _filterSet is not None:
                  _filterSet = self._field_info.filterSetSeq.wrapper(_filterSet)
          self._filterSetSeq = _filterSet
          self.checkUnloadedProperty(_filterSet,'filterSetLoaded')

      def isFilterSetLoaded(self):
          return self._filterSetLoaded

      def sizeOfFilterSet(self, current = None):
          self.errorIfUnloaded()
          if not self._filterSetLoaded: return -1
          return len(self._filterSetSeq)

      def copyFilterSet(self, current = None):
          self.errorIfUnloaded()
          if not self._filterSetLoaded: self.throwNullCollectionException("filterSetSeq")
          return list(self._filterSetSeq)

      def iterateFilterSet(self):
          self.errorIfUnloaded()
          if not self._filterSetLoaded: self.throwNullCollectionException("filterSetSeq")
          return iter(self._filterSetSeq)

      def addFilterSet(self, target, current = None):
          self.errorIfUnloaded()
          if not self._filterSetLoaded: self.throwNullCollectionException("filterSetSeq")
          self._filterSetSeq.append( target );
          target.setInstrument( self )

      def addAllFilterSetSet(self, targets, current = None):
          self.errorIfUnloaded()
          if  not self._filterSetLoaded: self.throwNullCollectionException("filterSetSeq")
          self._filterSetSeq.extend( targets )
          for target in targets:
              target.setInstrument( self )

      def removeFilterSet(self, target, current = None):
          self.errorIfUnloaded()
          if not self._filterSetLoaded: self.throwNullCollectionException("filterSetSeq")
          self._filterSetSeq.remove( target )
          target.setInstrument( None )

      def removeAllFilterSetSet(self, targets, current = None):
          self.errorIfUnloaded()
          if not self._filterSetLoaded: self.throwNullCollectionException("filterSetSeq")
          for elt in targets:
              elt.setInstrument( None )
              self._filterSetSeq.remove( elt )

      def clearFilterSet(self, current = None):
          self.errorIfUnloaded()
          if not self._filterSetLoaded: self.throwNullCollectionException("filterSetSeq")
          for elt in self._filterSetSeq:
              elt.setInstrument( None )
          self._filterSetSeq = list()

      def reloadFilterSet(self, toCopy, current = None):
          self.errorIfUnloaded()
          if self._filterSetLoaded:
              raise omero.ClientError("Cannot reload active collection: filterSetSeq")
          if not toCopy:
              raise omero.ClientError("Argument cannot be null")
          if toCopy.getId().getValue() != self.getId().getValue():
             raise omero.ClientError("Argument must have the same id as this instance")
          if toCopy.getDetails().getUpdateEvent().getId().getValue() < self.getDetails().getUpdateEvent().getId().getValue():
             raise omero.ClientError("Argument may not be older than this instance")
          copy = toCopy.copyFilterSet() # May also throw
          for elt in copy:
              elt.setInstrument( self )
          self._filterSetSeq = copy
          toCopy.unloadFilterSet()
          self._filterSetLoaded = True

      def unloadOtf(self, current = None):
          self._otfLoaded = False
          self._otfSeq = None;

      def _getOtf(self, current = None):
          self.errorIfUnloaded()
          return self._otfSeq

      def _setOtf(self, _otf, current = None, wrap=False):
          self.errorIfUnloaded()
          if wrap and self._field_info.otfSeq.wrapper is not None:
              if _otf is not None:
                  _otf = self._field_info.otfSeq.wrapper(_otf)
          self._otfSeq = _otf
          self.checkUnloadedProperty(_otf,'otfLoaded')

      def isOtfLoaded(self):
          return self._otfLoaded

      def sizeOfOtf(self, current = None):
          self.errorIfUnloaded()
          if not self._otfLoaded: return -1
          return len(self._otfSeq)

      def copyOtf(self, current = None):
          self.errorIfUnloaded()
          if not self._otfLoaded: self.throwNullCollectionException("otfSeq")
          return list(self._otfSeq)

      def iterateOtf(self):
          self.errorIfUnloaded()
          if not self._otfLoaded: self.throwNullCollectionException("otfSeq")
          return iter(self._otfSeq)

      def addOTF(self, target, current = None):
          self.errorIfUnloaded()
          if not self._otfLoaded: self.throwNullCollectionException("otfSeq")
          self._otfSeq.append( target );
          target.setInstrument( self )

      def addAllOTFSet(self, targets, current = None):
          self.errorIfUnloaded()
          if  not self._otfLoaded: self.throwNullCollectionException("otfSeq")
          self._otfSeq.extend( targets )
          for target in targets:
              target.setInstrument( self )

      def removeOTF(self, target, current = None):
          self.errorIfUnloaded()
          if not self._otfLoaded: self.throwNullCollectionException("otfSeq")
          self._otfSeq.remove( target )
          target.setInstrument( None )

      def removeAllOTFSet(self, targets, current = None):
          self.errorIfUnloaded()
          if not self._otfLoaded: self.throwNullCollectionException("otfSeq")
          for elt in targets:
              elt.setInstrument( None )
              self._otfSeq.remove( elt )

      def clearOtf(self, current = None):
          self.errorIfUnloaded()
          if not self._otfLoaded: self.throwNullCollectionException("otfSeq")
          for elt in self._otfSeq:
              elt.setInstrument( None )
          self._otfSeq = list()

      def reloadOtf(self, toCopy, current = None):
          self.errorIfUnloaded()
          if self._otfLoaded:
              raise omero.ClientError("Cannot reload active collection: otfSeq")
          if not toCopy:
              raise omero.ClientError("Argument cannot be null")
          if toCopy.getId().getValue() != self.getId().getValue():
             raise omero.ClientError("Argument must have the same id as this instance")
          if toCopy.getDetails().getUpdateEvent().getId().getValue() < self.getDetails().getUpdateEvent().getId().getValue():
             raise omero.ClientError("Argument may not be older than this instance")
          copy = toCopy.copyOtf() # May also throw
          for elt in copy:
              elt.setInstrument( self )
          self._otfSeq = copy
          toCopy.unloadOtf()
          self._otfLoaded = True

      def unloadAnnotationLinks(self, current = None):
          self._annotationLinksLoaded = False
          self._annotationLinksSeq = None;

      def _getAnnotationLinks(self, current = None):
          self.errorIfUnloaded()
          return self._annotationLinksSeq

      def _setAnnotationLinks(self, _annotationLinks, current = None, wrap=False):
          self.errorIfUnloaded()
          if wrap and self._field_info.annotationLinksSeq.wrapper is not None:
              if _annotationLinks is not None:
                  _annotationLinks = self._field_info.annotationLinksSeq.wrapper(_annotationLinks)
          self._annotationLinksSeq = _annotationLinks
          self.checkUnloadedProperty(_annotationLinks,'annotationLinksLoaded')

      def isAnnotationLinksLoaded(self):
          return self._annotationLinksLoaded

      def sizeOfAnnotationLinks(self, current = None):
          self.errorIfUnloaded()
          if not self._annotationLinksLoaded: return -1
          return len(self._annotationLinksSeq)

      def copyAnnotationLinks(self, current = None):
          self.errorIfUnloaded()
          if not self._annotationLinksLoaded: self.throwNullCollectionException("annotationLinksSeq")
          return list(self._annotationLinksSeq)

      def iterateAnnotationLinks(self):
          self.errorIfUnloaded()
          if not self._annotationLinksLoaded: self.throwNullCollectionException("annotationLinksSeq")
          return iter(self._annotationLinksSeq)

      def addInstrumentAnnotationLink(self, target, current = None):
          self.errorIfUnloaded()
          if not self._annotationLinksLoaded: self.throwNullCollectionException("annotationLinksSeq")
          self._annotationLinksSeq.append( target );
          target.setParent( self )

      def addAllInstrumentAnnotationLinkSet(self, targets, current = None):
          self.errorIfUnloaded()
          if  not self._annotationLinksLoaded: self.throwNullCollectionException("annotationLinksSeq")
          self._annotationLinksSeq.extend( targets )
          for target in targets:
              target.setParent( self )

      def removeInstrumentAnnotationLink(self, target, current = None):
          self.errorIfUnloaded()
          if not self._annotationLinksLoaded: self.throwNullCollectionException("annotationLinksSeq")
          self._annotationLinksSeq.remove( target )
          target.setParent( None )

      def removeAllInstrumentAnnotationLinkSet(self, targets, current = None):
          self.errorIfUnloaded()
          if not self._annotationLinksLoaded: self.throwNullCollectionException("annotationLinksSeq")
          for elt in targets:
              elt.setParent( None )
              self._annotationLinksSeq.remove( elt )

      def clearAnnotationLinks(self, current = None):
          self.errorIfUnloaded()
          if not self._annotationLinksLoaded: self.throwNullCollectionException("annotationLinksSeq")
          for elt in self._annotationLinksSeq:
              elt.setParent( None )
          self._annotationLinksSeq = list()

      def reloadAnnotationLinks(self, toCopy, current = None):
          self.errorIfUnloaded()
          if self._annotationLinksLoaded:
              raise omero.ClientError("Cannot reload active collection: annotationLinksSeq")
          if not toCopy:
              raise omero.ClientError("Argument cannot be null")
          if toCopy.getId().getValue() != self.getId().getValue():
             raise omero.ClientError("Argument must have the same id as this instance")
          if toCopy.getDetails().getUpdateEvent().getId().getValue() < self.getDetails().getUpdateEvent().getId().getValue():
             raise omero.ClientError("Argument may not be older than this instance")
          copy = toCopy.copyAnnotationLinks() # May also throw
          for elt in copy:
              elt.setParent( self )
          self._annotationLinksSeq = copy
          toCopy.unloadAnnotationLinks()
          self._annotationLinksLoaded = True

      def getAnnotationLinksCountPerOwner(self, current = None):
          return self._annotationLinksCountPerOwner

      def linkAnnotation(self, addition, current = None):
          self.errorIfUnloaded()
          if not self._annotationLinksLoaded: self.throwNullCollectionException("annotationLinksSeq")
          link = _omero_model.InstrumentAnnotationLinkI()
          link.link( self, addition );
          self.addInstrumentAnnotationLinkToBoth( link, True )
          return link

      def addInstrumentAnnotationLinkToBoth(self, link, bothSides):
          self.errorIfUnloaded()
          if not self._annotationLinksLoaded: self.throwNullCollectionException("annotationLinksSeq")
          self._annotationLinksSeq.append( link )

      def findInstrumentAnnotationLink(self, removal, current = None):
          self.errorIfUnloaded()
          if not self._annotationLinksLoaded: self.throwNullCollectionException("annotationLinksSeq")
          result = list()
          for link in self._annotationLinksSeq:
              if link.getChild() == removal: result.append(link)
          return result

      def unlinkAnnotation(self, removal, current = None):
          self.errorIfUnloaded()
          if not self._annotationLinksLoaded: self.throwNullCollectionException("annotationLinksSeq")
          toRemove = self.findInstrumentAnnotationLink(removal)
          for next in toRemove:
              self.removeInstrumentAnnotationLinkFromBoth( next, True )

      def removeInstrumentAnnotationLinkFromBoth(self, link, bothSides, current = None):
          self.errorIfUnloaded()
          if not self._annotationLinksLoaded: self.throwNullCollectionException("annotationLinksSeq")
          self._annotationLinksSeq.remove( link )

      def linkedAnnotationList(self, current = None):
          self.errorIfUnloaded()
          if not self.annotationLinksLoaded: self.throwNullCollectionException("AnnotationLinks")
          linked = []
          for link in self._annotationLinksSeq:
              linked.append( link.getChild() )
          return linked


      def ice_postUnmarshal(self):
          """
          Provides additional initialization once all data loaded
          """
          pass # Currently unused


      def ice_preMarshal(self):
          """
          Provides additional validation before data is sent
          """
          pass # Currently unused

      def __getattr__(self, name):
          """
          Reroutes all access to object.field through object.getField() or object.isField()
          """
          if "_" in name:  # Ice disallows underscores, so these should be treated normally.
              return object.__getattribute__(self, name)
          field  = "_" + name
          capitalized = name[0].capitalize() + name[1:]
          getter = "get" + capitalized
          questn = "is" + capitalized
          try:
              self.__dict__[field]
              if hasattr(self, getter):
                  method = getattr(self, getter)
                  return method()
              elif hasattr(self, questn):
                  method = getattr(self, questn)
                  return method()
          except:
              pass
          raise AttributeError("'%s' object has no attribute '%s' or '%s'" % (self.__class__.__name__, getter, questn))

      def __setattr__(self, name, value):
          """
          Reroutes all access to object.field through object.getField(), with the caveat
          that all sets on variables starting with "_" are permitted directly.
          """
          if name.startswith("_"):
              self.__dict__[name] = value
              return
          else:
              field  = "_" + name
              setter = "set" + name[0].capitalize() + name[1:]
              if hasattr(self, field) and hasattr(self, setter):
                  method = getattr(self, setter)
                  return method(value)
          raise AttributeError("'%s' object has no attribute '%s'" % (self.__class__.__name__, setter))

_omero_model.InstrumentI = InstrumentI



# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.4
#
# <auto-generated>
#
# Generated from file `RenderingDef.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import omero_model_IObject_ice
import omero_RTypes_ice
import omero_model_RTypes_ice
import omero_System_ice
import omero_Collections_ice

# Included module omero
_M_omero = Ice.openModule('omero')

# Included module omero.model
_M_omero.model = Ice.openModule('omero.model')

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Included module omero.sys
_M_omero.sys = Ice.openModule('omero.sys')

# Included module omero.api
_M_omero.api = Ice.openModule('omero.api')

# Start of module omero
__name__ = 'omero'

# Start of module omero.model
__name__ = 'omero.model'

if 'Pixels' not in _M_omero.model.__dict__:
    _M_omero.model._t_Pixels = IcePy.declareClass('::omero::model::Pixels')
    _M_omero.model._t_PixelsPrx = IcePy.declareProxy('::omero::model::Pixels')

if 'RenderingModel' not in _M_omero.model.__dict__:
    _M_omero.model._t_RenderingModel = IcePy.declareClass('::omero::model::RenderingModel')
    _M_omero.model._t_RenderingModelPrx = IcePy.declareProxy('::omero::model::RenderingModel')

if 'ChannelBinding' not in _M_omero.model.__dict__:
    _M_omero.model._t_ChannelBinding = IcePy.declareClass('::omero::model::ChannelBinding')
    _M_omero.model._t_ChannelBindingPrx = IcePy.declareProxy('::omero::model::ChannelBinding')

if 'QuantumDef' not in _M_omero.model.__dict__:
    _M_omero.model._t_QuantumDef = IcePy.declareClass('::omero::model::QuantumDef')
    _M_omero.model._t_QuantumDefPrx = IcePy.declareProxy('::omero::model::QuantumDef')

if 'ProjectionDef' not in _M_omero.model.__dict__:
    _M_omero.model._t_ProjectionDef = IcePy.declareClass('::omero::model::ProjectionDef')
    _M_omero.model._t_ProjectionDefPrx = IcePy.declareProxy('::omero::model::ProjectionDef')

if 'Details' not in _M_omero.model.__dict__:
    _M_omero.model._t_Details = IcePy.declareClass('::omero::model::Details')
    _M_omero.model._t_DetailsPrx = IcePy.declareProxy('::omero::model::Details')

if '_t_RenderingDefWaveRenderingSeq' not in _M_omero.model.__dict__:
    _M_omero.model._t_RenderingDefWaveRenderingSeq = IcePy.defineSequence('::omero::model::RenderingDefWaveRenderingSeq', (), _M_omero.model._t_ChannelBinding)

if '_t_RenderingDefProjectionsSeq' not in _M_omero.model.__dict__:
    _M_omero.model._t_RenderingDefProjectionsSeq = IcePy.defineSequence('::omero::model::RenderingDefProjectionsSeq', (), _M_omero.model._t_ProjectionDef)

if 'RenderingDef' not in _M_omero.model.__dict__:
    _M_omero.model.RenderingDef = Ice.createTempClass()
    class RenderingDef(_M_omero.model.IObject):
        def __init__(self, _id=None, _details=None, _loaded=False, _version=None, _pixels=None, _defaultZ=None, _defaultT=None, _model=None, _waveRenderingSeq=None, _waveRenderingLoaded=False, _name=None, _compression=None, _quantization=None, _projectionsSeq=None, _projectionsLoaded=False):
            if Ice.getType(self) == _M_omero.model.RenderingDef:
                raise RuntimeError('omero.model.RenderingDef is an abstract class')
            _M_omero.model.IObject.__init__(self, _id, _details, _loaded)
            self._version = _version
            self._pixels = _pixels
            self._defaultZ = _defaultZ
            self._defaultT = _defaultT
            self._model = _model
            self._waveRenderingSeq = _waveRenderingSeq
            self._waveRenderingLoaded = _waveRenderingLoaded
            self._name = _name
            self._compression = _compression
            self._quantization = _quantization
            self._projectionsSeq = _projectionsSeq
            self._projectionsLoaded = _projectionsLoaded

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::model::IObject', '::omero::model::RenderingDef')

        def ice_id(self, current=None):
            return '::omero::model::RenderingDef'

        def ice_staticId():
            return '::omero::model::RenderingDef'
        ice_staticId = staticmethod(ice_staticId)

        def getVersion(self, current=None):
            pass

        def setVersion(self, theVersion, current=None):
            pass

        def getPixels(self, current=None):
            pass

        def setPixels(self, thePixels, current=None):
            pass

        def getDefaultZ(self, current=None):
            pass

        def setDefaultZ(self, theDefaultZ, current=None):
            pass

        def getDefaultT(self, current=None):
            pass

        def setDefaultT(self, theDefaultT, current=None):
            pass

        def getModel(self, current=None):
            pass

        def setModel(self, theModel, current=None):
            pass

        def unloadWaveRendering(self, current=None):
            pass

        def sizeOfWaveRendering(self, current=None):
            pass

        def copyWaveRendering(self, current=None):
            pass

        def addChannelBinding(self, target, current=None):
            pass

        def addAllChannelBindingSet(self, targets, current=None):
            pass

        def removeChannelBinding(self, theTarget, current=None):
            pass

        def removeAllChannelBindingSet(self, targets, current=None):
            pass

        def clearWaveRendering(self, current=None):
            pass

        def reloadWaveRendering(self, toCopy, current=None):
            pass

        def getChannelBinding(self, index, current=None):
            pass

        def setChannelBinding(self, index, theElement, current=None):
            pass

        def getPrimaryChannelBinding(self, current=None):
            pass

        def setPrimaryChannelBinding(self, theElement, current=None):
            pass

        def getName(self, current=None):
            pass

        def setName(self, theName, current=None):
            pass

        def getCompression(self, current=None):
            pass

        def setCompression(self, theCompression, current=None):
            pass

        def getQuantization(self, current=None):
            pass

        def setQuantization(self, theQuantization, current=None):
            pass

        def unloadProjections(self, current=None):
            pass

        def sizeOfProjections(self, current=None):
            pass

        def copyProjections(self, current=None):
            pass

        def addProjectionDef(self, target, current=None):
            pass

        def addAllProjectionDefSet(self, targets, current=None):
            pass

        def removeProjectionDef(self, theTarget, current=None):
            pass

        def removeAllProjectionDefSet(self, targets, current=None):
            pass

        def clearProjections(self, current=None):
            pass

        def reloadProjections(self, toCopy, current=None):
            pass

        def getProjectionDef(self, index, current=None):
            pass

        def setProjectionDef(self, index, theElement, current=None):
            pass

        def getPrimaryProjectionDef(self, current=None):
            pass

        def setPrimaryProjectionDef(self, theElement, current=None):
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_omero.model._t_RenderingDef)

        __repr__ = __str__

    _M_omero.model.RenderingDefPrx = Ice.createTempClass()
    class RenderingDefPrx(_M_omero.model.IObjectPrx):

        def getVersion(self, _ctx=None):
            return _M_omero.model.RenderingDef._op_getVersion.invoke(self, ((), _ctx))

        def begin_getVersion(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.RenderingDef._op_getVersion.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getVersion(self, _r):
            return _M_omero.model.RenderingDef._op_getVersion.end(self, _r)

        def setVersion(self, theVersion, _ctx=None):
            return _M_omero.model.RenderingDef._op_setVersion.invoke(self, ((theVersion, ), _ctx))

        def begin_setVersion(self, theVersion, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.RenderingDef._op_setVersion.begin(self, ((theVersion, ), _response, _ex, _sent, _ctx))

        def end_setVersion(self, _r):
            return _M_omero.model.RenderingDef._op_setVersion.end(self, _r)

        def getPixels(self, _ctx=None):
            return _M_omero.model.RenderingDef._op_getPixels.invoke(self, ((), _ctx))

        def begin_getPixels(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.RenderingDef._op_getPixels.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getPixels(self, _r):
            return _M_omero.model.RenderingDef._op_getPixels.end(self, _r)

        def setPixels(self, thePixels, _ctx=None):
            return _M_omero.model.RenderingDef._op_setPixels.invoke(self, ((thePixels, ), _ctx))

        def begin_setPixels(self, thePixels, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.RenderingDef._op_setPixels.begin(self, ((thePixels, ), _response, _ex, _sent, _ctx))

        def end_setPixels(self, _r):
            return _M_omero.model.RenderingDef._op_setPixels.end(self, _r)

        def getDefaultZ(self, _ctx=None):
            return _M_omero.model.RenderingDef._op_getDefaultZ.invoke(self, ((), _ctx))

        def begin_getDefaultZ(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.RenderingDef._op_getDefaultZ.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getDefaultZ(self, _r):
            return _M_omero.model.RenderingDef._op_getDefaultZ.end(self, _r)

        def setDefaultZ(self, theDefaultZ, _ctx=None):
            return _M_omero.model.RenderingDef._op_setDefaultZ.invoke(self, ((theDefaultZ, ), _ctx))

        def begin_setDefaultZ(self, theDefaultZ, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.RenderingDef._op_setDefaultZ.begin(self, ((theDefaultZ, ), _response, _ex, _sent, _ctx))

        def end_setDefaultZ(self, _r):
            return _M_omero.model.RenderingDef._op_setDefaultZ.end(self, _r)

        def getDefaultT(self, _ctx=None):
            return _M_omero.model.RenderingDef._op_getDefaultT.invoke(self, ((), _ctx))

        def begin_getDefaultT(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.RenderingDef._op_getDefaultT.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getDefaultT(self, _r):
            return _M_omero.model.RenderingDef._op_getDefaultT.end(self, _r)

        def setDefaultT(self, theDefaultT, _ctx=None):
            return _M_omero.model.RenderingDef._op_setDefaultT.invoke(self, ((theDefaultT, ), _ctx))

        def begin_setDefaultT(self, theDefaultT, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.RenderingDef._op_setDefaultT.begin(self, ((theDefaultT, ), _response, _ex, _sent, _ctx))

        def end_setDefaultT(self, _r):
            return _M_omero.model.RenderingDef._op_setDefaultT.end(self, _r)

        def getModel(self, _ctx=None):
            return _M_omero.model.RenderingDef._op_getModel.invoke(self, ((), _ctx))

        def begin_getModel(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.RenderingDef._op_getModel.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getModel(self, _r):
            return _M_omero.model.RenderingDef._op_getModel.end(self, _r)

        def setModel(self, theModel, _ctx=None):
            return _M_omero.model.RenderingDef._op_setModel.invoke(self, ((theModel, ), _ctx))

        def begin_setModel(self, theModel, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.RenderingDef._op_setModel.begin(self, ((theModel, ), _response, _ex, _sent, _ctx))

        def end_setModel(self, _r):
            return _M_omero.model.RenderingDef._op_setModel.end(self, _r)

        def unloadWaveRendering(self, _ctx=None):
            return _M_omero.model.RenderingDef._op_unloadWaveRendering.invoke(self, ((), _ctx))

        def begin_unloadWaveRendering(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.RenderingDef._op_unloadWaveRendering.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_unloadWaveRendering(self, _r):
            return _M_omero.model.RenderingDef._op_unloadWaveRendering.end(self, _r)

        def sizeOfWaveRendering(self, _ctx=None):
            return _M_omero.model.RenderingDef._op_sizeOfWaveRendering.invoke(self, ((), _ctx))

        def begin_sizeOfWaveRendering(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.RenderingDef._op_sizeOfWaveRendering.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_sizeOfWaveRendering(self, _r):
            return _M_omero.model.RenderingDef._op_sizeOfWaveRendering.end(self, _r)

        def copyWaveRendering(self, _ctx=None):
            return _M_omero.model.RenderingDef._op_copyWaveRendering.invoke(self, ((), _ctx))

        def begin_copyWaveRendering(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.RenderingDef._op_copyWaveRendering.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_copyWaveRendering(self, _r):
            return _M_omero.model.RenderingDef._op_copyWaveRendering.end(self, _r)

        def addChannelBinding(self, target, _ctx=None):
            return _M_omero.model.RenderingDef._op_addChannelBinding.invoke(self, ((target, ), _ctx))

        def begin_addChannelBinding(self, target, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.RenderingDef._op_addChannelBinding.begin(self, ((target, ), _response, _ex, _sent, _ctx))

        def end_addChannelBinding(self, _r):
            return _M_omero.model.RenderingDef._op_addChannelBinding.end(self, _r)

        def addAllChannelBindingSet(self, targets, _ctx=None):
            return _M_omero.model.RenderingDef._op_addAllChannelBindingSet.invoke(self, ((targets, ), _ctx))

        def begin_addAllChannelBindingSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.RenderingDef._op_addAllChannelBindingSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_addAllChannelBindingSet(self, _r):
            return _M_omero.model.RenderingDef._op_addAllChannelBindingSet.end(self, _r)

        def removeChannelBinding(self, theTarget, _ctx=None):
            return _M_omero.model.RenderingDef._op_removeChannelBinding.invoke(self, ((theTarget, ), _ctx))

        def begin_removeChannelBinding(self, theTarget, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.RenderingDef._op_removeChannelBinding.begin(self, ((theTarget, ), _response, _ex, _sent, _ctx))

        def end_removeChannelBinding(self, _r):
            return _M_omero.model.RenderingDef._op_removeChannelBinding.end(self, _r)

        def removeAllChannelBindingSet(self, targets, _ctx=None):
            return _M_omero.model.RenderingDef._op_removeAllChannelBindingSet.invoke(self, ((targets, ), _ctx))

        def begin_removeAllChannelBindingSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.RenderingDef._op_removeAllChannelBindingSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_removeAllChannelBindingSet(self, _r):
            return _M_omero.model.RenderingDef._op_removeAllChannelBindingSet.end(self, _r)

        def clearWaveRendering(self, _ctx=None):
            return _M_omero.model.RenderingDef._op_clearWaveRendering.invoke(self, ((), _ctx))

        def begin_clearWaveRendering(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.RenderingDef._op_clearWaveRendering.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_clearWaveRendering(self, _r):
            return _M_omero.model.RenderingDef._op_clearWaveRendering.end(self, _r)

        def reloadWaveRendering(self, toCopy, _ctx=None):
            return _M_omero.model.RenderingDef._op_reloadWaveRendering.invoke(self, ((toCopy, ), _ctx))

        def begin_reloadWaveRendering(self, toCopy, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.RenderingDef._op_reloadWaveRendering.begin(self, ((toCopy, ), _response, _ex, _sent, _ctx))

        def end_reloadWaveRendering(self, _r):
            return _M_omero.model.RenderingDef._op_reloadWaveRendering.end(self, _r)

        def getChannelBinding(self, index, _ctx=None):
            return _M_omero.model.RenderingDef._op_getChannelBinding.invoke(self, ((index, ), _ctx))

        def begin_getChannelBinding(self, index, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.RenderingDef._op_getChannelBinding.begin(self, ((index, ), _response, _ex, _sent, _ctx))

        def end_getChannelBinding(self, _r):
            return _M_omero.model.RenderingDef._op_getChannelBinding.end(self, _r)

        def setChannelBinding(self, index, theElement, _ctx=None):
            return _M_omero.model.RenderingDef._op_setChannelBinding.invoke(self, ((index, theElement), _ctx))

        def begin_setChannelBinding(self, index, theElement, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.RenderingDef._op_setChannelBinding.begin(self, ((index, theElement), _response, _ex, _sent, _ctx))

        def end_setChannelBinding(self, _r):
            return _M_omero.model.RenderingDef._op_setChannelBinding.end(self, _r)

        def getPrimaryChannelBinding(self, _ctx=None):
            return _M_omero.model.RenderingDef._op_getPrimaryChannelBinding.invoke(self, ((), _ctx))

        def begin_getPrimaryChannelBinding(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.RenderingDef._op_getPrimaryChannelBinding.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getPrimaryChannelBinding(self, _r):
            return _M_omero.model.RenderingDef._op_getPrimaryChannelBinding.end(self, _r)

        def setPrimaryChannelBinding(self, theElement, _ctx=None):
            return _M_omero.model.RenderingDef._op_setPrimaryChannelBinding.invoke(self, ((theElement, ), _ctx))

        def begin_setPrimaryChannelBinding(self, theElement, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.RenderingDef._op_setPrimaryChannelBinding.begin(self, ((theElement, ), _response, _ex, _sent, _ctx))

        def end_setPrimaryChannelBinding(self, _r):
            return _M_omero.model.RenderingDef._op_setPrimaryChannelBinding.end(self, _r)

        def getName(self, _ctx=None):
            return _M_omero.model.RenderingDef._op_getName.invoke(self, ((), _ctx))

        def begin_getName(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.RenderingDef._op_getName.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getName(self, _r):
            return _M_omero.model.RenderingDef._op_getName.end(self, _r)

        def setName(self, theName, _ctx=None):
            return _M_omero.model.RenderingDef._op_setName.invoke(self, ((theName, ), _ctx))

        def begin_setName(self, theName, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.RenderingDef._op_setName.begin(self, ((theName, ), _response, _ex, _sent, _ctx))

        def end_setName(self, _r):
            return _M_omero.model.RenderingDef._op_setName.end(self, _r)

        def getCompression(self, _ctx=None):
            return _M_omero.model.RenderingDef._op_getCompression.invoke(self, ((), _ctx))

        def begin_getCompression(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.RenderingDef._op_getCompression.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getCompression(self, _r):
            return _M_omero.model.RenderingDef._op_getCompression.end(self, _r)

        def setCompression(self, theCompression, _ctx=None):
            return _M_omero.model.RenderingDef._op_setCompression.invoke(self, ((theCompression, ), _ctx))

        def begin_setCompression(self, theCompression, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.RenderingDef._op_setCompression.begin(self, ((theCompression, ), _response, _ex, _sent, _ctx))

        def end_setCompression(self, _r):
            return _M_omero.model.RenderingDef._op_setCompression.end(self, _r)

        def getQuantization(self, _ctx=None):
            return _M_omero.model.RenderingDef._op_getQuantization.invoke(self, ((), _ctx))

        def begin_getQuantization(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.RenderingDef._op_getQuantization.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getQuantization(self, _r):
            return _M_omero.model.RenderingDef._op_getQuantization.end(self, _r)

        def setQuantization(self, theQuantization, _ctx=None):
            return _M_omero.model.RenderingDef._op_setQuantization.invoke(self, ((theQuantization, ), _ctx))

        def begin_setQuantization(self, theQuantization, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.RenderingDef._op_setQuantization.begin(self, ((theQuantization, ), _response, _ex, _sent, _ctx))

        def end_setQuantization(self, _r):
            return _M_omero.model.RenderingDef._op_setQuantization.end(self, _r)

        def unloadProjections(self, _ctx=None):
            return _M_omero.model.RenderingDef._op_unloadProjections.invoke(self, ((), _ctx))

        def begin_unloadProjections(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.RenderingDef._op_unloadProjections.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_unloadProjections(self, _r):
            return _M_omero.model.RenderingDef._op_unloadProjections.end(self, _r)

        def sizeOfProjections(self, _ctx=None):
            return _M_omero.model.RenderingDef._op_sizeOfProjections.invoke(self, ((), _ctx))

        def begin_sizeOfProjections(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.RenderingDef._op_sizeOfProjections.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_sizeOfProjections(self, _r):
            return _M_omero.model.RenderingDef._op_sizeOfProjections.end(self, _r)

        def copyProjections(self, _ctx=None):
            return _M_omero.model.RenderingDef._op_copyProjections.invoke(self, ((), _ctx))

        def begin_copyProjections(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.RenderingDef._op_copyProjections.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_copyProjections(self, _r):
            return _M_omero.model.RenderingDef._op_copyProjections.end(self, _r)

        def addProjectionDef(self, target, _ctx=None):
            return _M_omero.model.RenderingDef._op_addProjectionDef.invoke(self, ((target, ), _ctx))

        def begin_addProjectionDef(self, target, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.RenderingDef._op_addProjectionDef.begin(self, ((target, ), _response, _ex, _sent, _ctx))

        def end_addProjectionDef(self, _r):
            return _M_omero.model.RenderingDef._op_addProjectionDef.end(self, _r)

        def addAllProjectionDefSet(self, targets, _ctx=None):
            return _M_omero.model.RenderingDef._op_addAllProjectionDefSet.invoke(self, ((targets, ), _ctx))

        def begin_addAllProjectionDefSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.RenderingDef._op_addAllProjectionDefSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_addAllProjectionDefSet(self, _r):
            return _M_omero.model.RenderingDef._op_addAllProjectionDefSet.end(self, _r)

        def removeProjectionDef(self, theTarget, _ctx=None):
            return _M_omero.model.RenderingDef._op_removeProjectionDef.invoke(self, ((theTarget, ), _ctx))

        def begin_removeProjectionDef(self, theTarget, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.RenderingDef._op_removeProjectionDef.begin(self, ((theTarget, ), _response, _ex, _sent, _ctx))

        def end_removeProjectionDef(self, _r):
            return _M_omero.model.RenderingDef._op_removeProjectionDef.end(self, _r)

        def removeAllProjectionDefSet(self, targets, _ctx=None):
            return _M_omero.model.RenderingDef._op_removeAllProjectionDefSet.invoke(self, ((targets, ), _ctx))

        def begin_removeAllProjectionDefSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.RenderingDef._op_removeAllProjectionDefSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_removeAllProjectionDefSet(self, _r):
            return _M_omero.model.RenderingDef._op_removeAllProjectionDefSet.end(self, _r)

        def clearProjections(self, _ctx=None):
            return _M_omero.model.RenderingDef._op_clearProjections.invoke(self, ((), _ctx))

        def begin_clearProjections(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.RenderingDef._op_clearProjections.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_clearProjections(self, _r):
            return _M_omero.model.RenderingDef._op_clearProjections.end(self, _r)

        def reloadProjections(self, toCopy, _ctx=None):
            return _M_omero.model.RenderingDef._op_reloadProjections.invoke(self, ((toCopy, ), _ctx))

        def begin_reloadProjections(self, toCopy, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.RenderingDef._op_reloadProjections.begin(self, ((toCopy, ), _response, _ex, _sent, _ctx))

        def end_reloadProjections(self, _r):
            return _M_omero.model.RenderingDef._op_reloadProjections.end(self, _r)

        def getProjectionDef(self, index, _ctx=None):
            return _M_omero.model.RenderingDef._op_getProjectionDef.invoke(self, ((index, ), _ctx))

        def begin_getProjectionDef(self, index, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.RenderingDef._op_getProjectionDef.begin(self, ((index, ), _response, _ex, _sent, _ctx))

        def end_getProjectionDef(self, _r):
            return _M_omero.model.RenderingDef._op_getProjectionDef.end(self, _r)

        def setProjectionDef(self, index, theElement, _ctx=None):
            return _M_omero.model.RenderingDef._op_setProjectionDef.invoke(self, ((index, theElement), _ctx))

        def begin_setProjectionDef(self, index, theElement, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.RenderingDef._op_setProjectionDef.begin(self, ((index, theElement), _response, _ex, _sent, _ctx))

        def end_setProjectionDef(self, _r):
            return _M_omero.model.RenderingDef._op_setProjectionDef.end(self, _r)

        def getPrimaryProjectionDef(self, _ctx=None):
            return _M_omero.model.RenderingDef._op_getPrimaryProjectionDef.invoke(self, ((), _ctx))

        def begin_getPrimaryProjectionDef(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.RenderingDef._op_getPrimaryProjectionDef.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getPrimaryProjectionDef(self, _r):
            return _M_omero.model.RenderingDef._op_getPrimaryProjectionDef.end(self, _r)

        def setPrimaryProjectionDef(self, theElement, _ctx=None):
            return _M_omero.model.RenderingDef._op_setPrimaryProjectionDef.invoke(self, ((theElement, ), _ctx))

        def begin_setPrimaryProjectionDef(self, theElement, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.RenderingDef._op_setPrimaryProjectionDef.begin(self, ((theElement, ), _response, _ex, _sent, _ctx))

        def end_setPrimaryProjectionDef(self, _r):
            return _M_omero.model.RenderingDef._op_setPrimaryProjectionDef.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.model.RenderingDefPrx.ice_checkedCast(proxy, '::omero::model::RenderingDef', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.model.RenderingDefPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::model::RenderingDef'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.model._t_RenderingDefPrx = IcePy.defineProxy('::omero::model::RenderingDef', RenderingDefPrx)

    _M_omero.model._t_RenderingDef = IcePy.declareClass('::omero::model::RenderingDef')

    _M_omero.model._t_RenderingDef = IcePy.defineClass('::omero::model::RenderingDef', RenderingDef, -1, (), True, False, _M_omero.model._t_IObject, (), (
        ('_version', (), _M_omero._t_RInt, False, 0),
        ('_pixels', (), _M_omero.model._t_Pixels, False, 0),
        ('_defaultZ', (), _M_omero._t_RInt, False, 0),
        ('_defaultT', (), _M_omero._t_RInt, False, 0),
        ('_model', (), _M_omero.model._t_RenderingModel, False, 0),
        ('_waveRenderingSeq', (), _M_omero.model._t_RenderingDefWaveRenderingSeq, False, 0),
        ('_waveRenderingLoaded', (), IcePy._t_bool, False, 0),
        ('_name', (), _M_omero._t_RString, False, 0),
        ('_compression', (), _M_omero._t_RDouble, False, 0),
        ('_quantization', (), _M_omero.model._t_QuantumDef, False, 0),
        ('_projectionsSeq', (), _M_omero.model._t_RenderingDefProjectionsSeq, False, 0),
        ('_projectionsLoaded', (), IcePy._t_bool, False, 0)
    ))
    RenderingDef._ice_type = _M_omero.model._t_RenderingDef

    RenderingDef._op_getVersion = IcePy.Operation('getVersion', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    RenderingDef._op_setVersion = IcePy.Operation('setVersion', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    RenderingDef._op_getPixels = IcePy.Operation('getPixels', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_Pixels, False, 0), ())
    RenderingDef._op_setPixels = IcePy.Operation('setPixels', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Pixels, False, 0),), (), None, ())
    RenderingDef._op_getDefaultZ = IcePy.Operation('getDefaultZ', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    RenderingDef._op_setDefaultZ = IcePy.Operation('setDefaultZ', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    RenderingDef._op_getDefaultT = IcePy.Operation('getDefaultT', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    RenderingDef._op_setDefaultT = IcePy.Operation('setDefaultT', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    RenderingDef._op_getModel = IcePy.Operation('getModel', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_RenderingModel, False, 0), ())
    RenderingDef._op_setModel = IcePy.Operation('setModel', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_RenderingModel, False, 0),), (), None, ())
    RenderingDef._op_unloadWaveRendering = IcePy.Operation('unloadWaveRendering', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    RenderingDef._op_sizeOfWaveRendering = IcePy.Operation('sizeOfWaveRendering', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), IcePy._t_int, False, 0), ())
    RenderingDef._op_copyWaveRendering = IcePy.Operation('copyWaveRendering', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_RenderingDefWaveRenderingSeq, False, 0), ())
    RenderingDef._op_addChannelBinding = IcePy.Operation('addChannelBinding', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ChannelBinding, False, 0),), (), None, ())
    RenderingDef._op_addAllChannelBindingSet = IcePy.Operation('addAllChannelBindingSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_RenderingDefWaveRenderingSeq, False, 0),), (), None, ())
    RenderingDef._op_removeChannelBinding = IcePy.Operation('removeChannelBinding', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ChannelBinding, False, 0),), (), None, ())
    RenderingDef._op_removeAllChannelBindingSet = IcePy.Operation('removeAllChannelBindingSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_RenderingDefWaveRenderingSeq, False, 0),), (), None, ())
    RenderingDef._op_clearWaveRendering = IcePy.Operation('clearWaveRendering', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    RenderingDef._op_reloadWaveRendering = IcePy.Operation('reloadWaveRendering', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_RenderingDef, False, 0),), (), None, ())
    RenderingDef._op_getChannelBinding = IcePy.Operation('getChannelBinding', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), IcePy._t_int, False, 0),), (), ((), _M_omero.model._t_ChannelBinding, False, 0), ())
    RenderingDef._op_setChannelBinding = IcePy.Operation('setChannelBinding', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), IcePy._t_int, False, 0), ((), _M_omero.model._t_ChannelBinding, False, 0)), (), ((), _M_omero.model._t_ChannelBinding, False, 0), ())
    RenderingDef._op_getPrimaryChannelBinding = IcePy.Operation('getPrimaryChannelBinding', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_ChannelBinding, False, 0), ())
    RenderingDef._op_setPrimaryChannelBinding = IcePy.Operation('setPrimaryChannelBinding', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ChannelBinding, False, 0),), (), ((), _M_omero.model._t_ChannelBinding, False, 0), ())
    RenderingDef._op_getName = IcePy.Operation('getName', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RString, False, 0), ())
    RenderingDef._op_setName = IcePy.Operation('setName', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RString, False, 0),), (), None, ())
    RenderingDef._op_getCompression = IcePy.Operation('getCompression', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RDouble, False, 0), ())
    RenderingDef._op_setCompression = IcePy.Operation('setCompression', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RDouble, False, 0),), (), None, ())
    RenderingDef._op_getQuantization = IcePy.Operation('getQuantization', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_QuantumDef, False, 0), ())
    RenderingDef._op_setQuantization = IcePy.Operation('setQuantization', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_QuantumDef, False, 0),), (), None, ())
    RenderingDef._op_unloadProjections = IcePy.Operation('unloadProjections', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    RenderingDef._op_sizeOfProjections = IcePy.Operation('sizeOfProjections', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), IcePy._t_int, False, 0), ())
    RenderingDef._op_copyProjections = IcePy.Operation('copyProjections', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_RenderingDefProjectionsSeq, False, 0), ())
    RenderingDef._op_addProjectionDef = IcePy.Operation('addProjectionDef', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ProjectionDef, False, 0),), (), None, ())
    RenderingDef._op_addAllProjectionDefSet = IcePy.Operation('addAllProjectionDefSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_RenderingDefProjectionsSeq, False, 0),), (), None, ())
    RenderingDef._op_removeProjectionDef = IcePy.Operation('removeProjectionDef', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ProjectionDef, False, 0),), (), None, ())
    RenderingDef._op_removeAllProjectionDefSet = IcePy.Operation('removeAllProjectionDefSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_RenderingDefProjectionsSeq, False, 0),), (), None, ())
    RenderingDef._op_clearProjections = IcePy.Operation('clearProjections', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    RenderingDef._op_reloadProjections = IcePy.Operation('reloadProjections', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_RenderingDef, False, 0),), (), None, ())
    RenderingDef._op_getProjectionDef = IcePy.Operation('getProjectionDef', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), IcePy._t_int, False, 0),), (), ((), _M_omero.model._t_ProjectionDef, False, 0), ())
    RenderingDef._op_setProjectionDef = IcePy.Operation('setProjectionDef', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), IcePy._t_int, False, 0), ((), _M_omero.model._t_ProjectionDef, False, 0)), (), ((), _M_omero.model._t_ProjectionDef, False, 0), ())
    RenderingDef._op_getPrimaryProjectionDef = IcePy.Operation('getPrimaryProjectionDef', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_ProjectionDef, False, 0), ())
    RenderingDef._op_setPrimaryProjectionDef = IcePy.Operation('setPrimaryProjectionDef', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ProjectionDef, False, 0),), (), ((), _M_omero.model._t_ProjectionDef, False, 0), ())

    _M_omero.model.RenderingDef = RenderingDef
    del RenderingDef

    _M_omero.model.RenderingDefPrx = RenderingDefPrx
    del RenderingDefPrx

# End of module omero.model

__name__ = 'omero'

# End of module omero



# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.4
#
# <auto-generated>
#
# Generated from file `IMetadata.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import omero_ServicesF_ice
import omero_System_ice
import omero_Collections_ice

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Included module Glacier2
_M_Glacier2 = Ice.openModule('Glacier2')

# Included module omero
_M_omero = Ice.openModule('omero')

# Included module omero.model
_M_omero.model = Ice.openModule('omero.model')

# Included module omero.sys
_M_omero.sys = Ice.openModule('omero.sys')

# Included module omero.api
_M_omero.api = Ice.openModule('omero.api')

# Included module omero.grid
_M_omero.grid = Ice.openModule('omero.grid')

# Start of module omero
__name__ = 'omero'

# Start of module omero.api
__name__ = 'omero.api'

if 'IMetadata' not in _M_omero.api.__dict__:
    _M_omero.api.IMetadata = Ice.createTempClass()
    class IMetadata(_M_omero.api.ServiceInterface):
        """
        Provides method to interact with acquisition metadata and
        annotations.
        """
        def __init__(self):
            if Ice.getType(self) == _M_omero.api.IMetadata:
                raise RuntimeError('omero.api.IMetadata is an abstract class')

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::api::IMetadata', '::omero::api::ServiceInterface')

        def ice_id(self, current=None):
            return '::omero::api::IMetadata'

        def ice_staticId():
            return '::omero::api::IMetadata'
        ice_staticId = staticmethod(ice_staticId)

        def loadChannelAcquisitionData_async(self, _cb, ids, current=None):
            """
            Loads the logical channels and the acquisition metadata
            related to them.
            Arguments:
            _cb -- The asynchronous callback object.
            ids -- The collection of logical channel's ids. Mustn't be null.
            current -- The Current object for the invocation.
            """
            pass

        def loadAnnotations_async(self, _cb, rootType, rootIds, annotationTypes, annotatorIds, options, current=None):
            """
            Loads all the annotations of given types, that have been
            attached to the specified rootNodes for the
            specified annotatorIds.
            If no types specified, all annotations will be loaded.
            This method looks for the annotations that have been
            attached to each of the specified objects. It then maps
            each rootId onto the set of annotations
            that were found for that node. If no annotations were found
            for that node, then the entry will be null.
            Otherwise it will be a Map containing
            omero.model.Annotation objects.
            Arguments:
            _cb -- The asynchronous callback object.
            rootType -- The type of the nodes the annotations are linked to. Mustn't be null.
            rootIds -- Ids of the objects of type rootType. Mustn't be null.
            annotationTypes -- The types of annotation to retrieve. If null all annotations will be loaded. String of the type omero.model.annotations.*.
            annotatorIds -- Ids of the users for whom annotations should be retrieved. If null, all annotations returned.
            options -- 
            current -- The Current object for the invocation.
            """
            pass

        def loadSpecifiedAnnotations_async(self, _cb, annotationType, include, exclude, options, current=None):
            """
            Loads all the annotations of a given type.
            It is possible to filter the annotations by including or
            excluding name spaces set on the annotations.
            Arguments:
            _cb -- The asynchronous callback object.
            annotationType -- The type of annotations to load.
            include -- Include the annotations with the specified name spaces.
            exclude -- Exclude the annotations with the specified name spaces.
            options -- The POJO options.
            current -- The Current object for the invocation.
            """
            pass

        def loadTagContent_async(self, _cb, ids, options, current=None):
            """
            Loads the TagSet if the id is specified otherwise loads
            all the TagSet.
            Arguments:
            _cb -- The asynchronous callback object.
            ids -- The id of the tag to load or -1.
            options -- 
            current -- The Current object for the invocation.
            """
            pass

        def loadTagSets_async(self, _cb, options, current=None):
            """
            Loads all the TagSets. Returns a collection of
            AnnotationAnnotatioLink objects and, if the
            orphan parameters is true, the
            TagAnnotation object.
            Note that the difference between a TagSet and a Tag is made
            using the NS_INSIGHT_TAG_SET namespace.
            Arguments:
            _cb -- The asynchronous callback object.
            options -- The POJO options.
            current -- The Current object for the invocation.
            """
            pass

        def getTaggedObjectsCount_async(self, _cb, ids, options, current=None):
            """
            Returns a map whose key is a tag id and the value the
            number of Projects, Datasets, and Images linked to that tag.
            Arguments:
            _cb -- The asynchronous callback object.
            ids -- The collection of ids.
            options -- The POJO options.
            current -- The Current object for the invocation.
            """
            pass

        def countSpecifiedAnnotations_async(self, _cb, annotationType, include, exclude, options, current=None):
            """
            Counts the number of annotation of a given type.
            Arguments:
            _cb -- The asynchronous callback object.
            annotationType -- The type of annotations to load.
            include -- The collection of name space, one of the constants defined by this class.
            exclude -- The collection of name space, one of the constants defined by this class.
            options -- The POJO options.
            current -- The Current object for the invocation.
            """
            pass

        def loadAnnotation_async(self, _cb, annotationIds, current=None):
            """
            Loads the specified annotations.
            Arguments:
            _cb -- The asynchronous callback object.
            annotationIds -- The collection of annotation ids.
            current -- The Current object for the invocation.
            """
            pass

        def loadInstrument_async(self, _cb, id, current=None):
            """
            Loads the instrument and its components i.e. detectors,
            objectives, etc.
            Arguments:
            _cb -- The asynchronous callback object.
            id -- The id of the instrument to load.
            current -- The Current object for the invocation.
            """
            pass

        def loadAnnotationsUsedNotOwned_async(self, _cb, annotationType, userID, current=None):
            """
            Loads the annotations of a given type used by the specified
            user but not owned by the user.
            Arguments:
            _cb -- The asynchronous callback object.
            annotationType -- The type of annotations to load.
            userID -- The identifier of the user.
            current -- The Current object for the invocation.
            """
            pass

        def countAnnotationsUsedNotOwned_async(self, _cb, annotationType, userID, current=None):
            """
            Counts the number of annotation of a given type used by the
            specified user but not owned by the user.
            Arguments:
            _cb -- The asynchronous callback object.
            annotationType -- The type of annotations to load.
            userID -- The identifier of the user.
            current -- The Current object for the invocation.
            """
            pass

        def loadSpecifiedAnnotationsLinkedTo_async(self, _cb, annotationType, include, exclude, rootNodeType, rootNodeIds, options, current=None):
            """
            Loads the annotations of a given type linked to the
            specified objects. It is possible to filter the annotations
            by including or excluding name spaces set on the
            annotations.
            This method looks for the annotations that have been
            attached to each of the specified objects. It then maps
            each rootNodeId onto the set of annotations
            that were found for that node. If no annotations were found
            for that node, the map will not contain an entry for that
            node. Otherwise it will be a Set containing
            omero.model.Annotation objects.
            The rootNodeType supported are:
            Project, Dataset, Image, Pixels, Screen, Plate,
            PlateAcquisition, Well, Fileset.
            Arguments:
            _cb -- The asynchronous callback object.
            annotationType -- The type of annotations to load.
            include -- Include the annotations with the specified name spaces.
            exclude -- Exclude the annotations with the specified name spaces.
            rootNodeType -- The type of objects the annotations are linked to.
            rootNodeIds -- The identifiers of the objects.
            options -- The POJO options.
            current -- The Current object for the invocation.
            """
            pass

        def loadLogFiles_async(self, _cb, rootType, ids, current=None):
            """
            Finds the original file IDs for the import logs
            corresponding to the given Image or Fileset IDs.
            Arguments:
            _cb -- The asynchronous callback object.
            rootType -- the root node type, may be omero.model.Image or omero.model.Fileset
            ids -- the IDs of the entities for which the import log original file IDs are required
            current -- The Current object for the invocation.
            """
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_omero.api._t_IMetadata)

        __repr__ = __str__

    _M_omero.api.IMetadataPrx = Ice.createTempClass()
    class IMetadataPrx(_M_omero.api.ServiceInterfacePrx):

        """
        Loads the logical channels and the acquisition metadata
        related to them.
        Arguments:
        ids -- The collection of logical channel's ids. Mustn't be null.
        _ctx -- The request context for the invocation.
        Returns: The collection of loaded logical channels.
        """
        def loadChannelAcquisitionData(self, ids, _ctx=None):
            return _M_omero.api.IMetadata._op_loadChannelAcquisitionData.invoke(self, ((ids, ), _ctx))

        """
        Loads the logical channels and the acquisition metadata
        related to them.
        Arguments:
        ids -- The collection of logical channel's ids. Mustn't be null.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_loadChannelAcquisitionData(self, ids, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.IMetadata._op_loadChannelAcquisitionData.begin(self, ((ids, ), _response, _ex, _sent, _ctx))

        """
        Loads the logical channels and the acquisition metadata
        related to them.
        Arguments:
        ids -- The collection of logical channel's ids. Mustn't be null.
        Returns: The collection of loaded logical channels.
        """
        def end_loadChannelAcquisitionData(self, _r):
            return _M_omero.api.IMetadata._op_loadChannelAcquisitionData.end(self, _r)

        """
        Loads all the annotations of given types, that have been
        attached to the specified rootNodes for the
        specified annotatorIds.
        If no types specified, all annotations will be loaded.
        This method looks for the annotations that have been
        attached to each of the specified objects. It then maps
        each rootId onto the set of annotations
        that were found for that node. If no annotations were found
        for that node, then the entry will be null.
        Otherwise it will be a Map containing
        omero.model.Annotation objects.
        Arguments:
        rootType -- The type of the nodes the annotations are linked to. Mustn't be null.
        rootIds -- Ids of the objects of type rootType. Mustn't be null.
        annotationTypes -- The types of annotation to retrieve. If null all annotations will be loaded. String of the type omero.model.annotations.*.
        annotatorIds -- Ids of the users for whom annotations should be retrieved. If null, all annotations returned.
        options -- 
        _ctx -- The request context for the invocation.
        Returns: A map whose key is rootId and value the Map of all annotations for that node or null.
        """
        def loadAnnotations(self, rootType, rootIds, annotationTypes, annotatorIds, options, _ctx=None):
            return _M_omero.api.IMetadata._op_loadAnnotations.invoke(self, ((rootType, rootIds, annotationTypes, annotatorIds, options), _ctx))

        """
        Loads all the annotations of given types, that have been
        attached to the specified rootNodes for the
        specified annotatorIds.
        If no types specified, all annotations will be loaded.
        This method looks for the annotations that have been
        attached to each of the specified objects. It then maps
        each rootId onto the set of annotations
        that were found for that node. If no annotations were found
        for that node, then the entry will be null.
        Otherwise it will be a Map containing
        omero.model.Annotation objects.
        Arguments:
        rootType -- The type of the nodes the annotations are linked to. Mustn't be null.
        rootIds -- Ids of the objects of type rootType. Mustn't be null.
        annotationTypes -- The types of annotation to retrieve. If null all annotations will be loaded. String of the type omero.model.annotations.*.
        annotatorIds -- Ids of the users for whom annotations should be retrieved. If null, all annotations returned.
        options -- 
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_loadAnnotations(self, rootType, rootIds, annotationTypes, annotatorIds, options, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.IMetadata._op_loadAnnotations.begin(self, ((rootType, rootIds, annotationTypes, annotatorIds, options), _response, _ex, _sent, _ctx))

        """
        Loads all the annotations of given types, that have been
        attached to the specified rootNodes for the
        specified annotatorIds.
        If no types specified, all annotations will be loaded.
        This method looks for the annotations that have been
        attached to each of the specified objects. It then maps
        each rootId onto the set of annotations
        that were found for that node. If no annotations were found
        for that node, then the entry will be null.
        Otherwise it will be a Map containing
        omero.model.Annotation objects.
        Arguments:
        rootType -- The type of the nodes the annotations are linked to. Mustn't be null.
        rootIds -- Ids of the objects of type rootType. Mustn't be null.
        annotationTypes -- The types of annotation to retrieve. If null all annotations will be loaded. String of the type omero.model.annotations.*.
        annotatorIds -- Ids of the users for whom annotations should be retrieved. If null, all annotations returned.
        options -- 
        Returns: A map whose key is rootId and value the Map of all annotations for that node or null.
        """
        def end_loadAnnotations(self, _r):
            return _M_omero.api.IMetadata._op_loadAnnotations.end(self, _r)

        """
        Loads all the annotations of a given type.
        It is possible to filter the annotations by including or
        excluding name spaces set on the annotations.
        Arguments:
        annotationType -- The type of annotations to load.
        include -- Include the annotations with the specified name spaces.
        exclude -- Exclude the annotations with the specified name spaces.
        options -- The POJO options.
        _ctx -- The request context for the invocation.
        Returns: A collection of found annotations.
        """
        def loadSpecifiedAnnotations(self, annotationType, include, exclude, options, _ctx=None):
            return _M_omero.api.IMetadata._op_loadSpecifiedAnnotations.invoke(self, ((annotationType, include, exclude, options), _ctx))

        """
        Loads all the annotations of a given type.
        It is possible to filter the annotations by including or
        excluding name spaces set on the annotations.
        Arguments:
        annotationType -- The type of annotations to load.
        include -- Include the annotations with the specified name spaces.
        exclude -- Exclude the annotations with the specified name spaces.
        options -- The POJO options.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_loadSpecifiedAnnotations(self, annotationType, include, exclude, options, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.IMetadata._op_loadSpecifiedAnnotations.begin(self, ((annotationType, include, exclude, options), _response, _ex, _sent, _ctx))

        """
        Loads all the annotations of a given type.
        It is possible to filter the annotations by including or
        excluding name spaces set on the annotations.
        Arguments:
        annotationType -- The type of annotations to load.
        include -- Include the annotations with the specified name spaces.
        exclude -- Exclude the annotations with the specified name spaces.
        options -- The POJO options.
        Returns: A collection of found annotations.
        """
        def end_loadSpecifiedAnnotations(self, _r):
            return _M_omero.api.IMetadata._op_loadSpecifiedAnnotations.end(self, _r)

        """
        Loads the TagSet if the id is specified otherwise loads
        all the TagSet.
        Arguments:
        ids -- The id of the tag to load or -1.
        options -- 
        _ctx -- The request context for the invocation.
        Returns: Map whose key is a Tag/TagSet and the value either a Map or a list of related DataObject.
        """
        def loadTagContent(self, ids, options, _ctx=None):
            return _M_omero.api.IMetadata._op_loadTagContent.invoke(self, ((ids, options), _ctx))

        """
        Loads the TagSet if the id is specified otherwise loads
        all the TagSet.
        Arguments:
        ids -- The id of the tag to load or -1.
        options -- 
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_loadTagContent(self, ids, options, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.IMetadata._op_loadTagContent.begin(self, ((ids, options), _response, _ex, _sent, _ctx))

        """
        Loads the TagSet if the id is specified otherwise loads
        all the TagSet.
        Arguments:
        ids -- The id of the tag to load or -1.
        options -- 
        Returns: Map whose key is a Tag/TagSet and the value either a Map or a list of related DataObject.
        """
        def end_loadTagContent(self, _r):
            return _M_omero.api.IMetadata._op_loadTagContent.end(self, _r)

        """
        Loads all the TagSets. Returns a collection of
        AnnotationAnnotatioLink objects and, if the
        orphan parameters is true, the
        TagAnnotation object.
        Note that the difference between a TagSet and a Tag is made
        using the NS_INSIGHT_TAG_SET namespace.
        Arguments:
        options -- The POJO options.
        _ctx -- The request context for the invocation.
        Returns: See above.
        """
        def loadTagSets(self, options, _ctx=None):
            return _M_omero.api.IMetadata._op_loadTagSets.invoke(self, ((options, ), _ctx))

        """
        Loads all the TagSets. Returns a collection of
        AnnotationAnnotatioLink objects and, if the
        orphan parameters is true, the
        TagAnnotation object.
        Note that the difference between a TagSet and a Tag is made
        using the NS_INSIGHT_TAG_SET namespace.
        Arguments:
        options -- The POJO options.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_loadTagSets(self, options, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.IMetadata._op_loadTagSets.begin(self, ((options, ), _response, _ex, _sent, _ctx))

        """
        Loads all the TagSets. Returns a collection of
        AnnotationAnnotatioLink objects and, if the
        orphan parameters is true, the
        TagAnnotation object.
        Note that the difference between a TagSet and a Tag is made
        using the NS_INSIGHT_TAG_SET namespace.
        Arguments:
        options -- The POJO options.
        Returns: See above.
        """
        def end_loadTagSets(self, _r):
            return _M_omero.api.IMetadata._op_loadTagSets.end(self, _r)

        """
        Returns a map whose key is a tag id and the value the
        number of Projects, Datasets, and Images linked to that tag.
        Arguments:
        ids -- The collection of ids.
        options -- The POJO options.
        _ctx -- The request context for the invocation.
        Returns: See above.
        """
        def getTaggedObjectsCount(self, ids, options, _ctx=None):
            return _M_omero.api.IMetadata._op_getTaggedObjectsCount.invoke(self, ((ids, options), _ctx))

        """
        Returns a map whose key is a tag id and the value the
        number of Projects, Datasets, and Images linked to that tag.
        Arguments:
        ids -- The collection of ids.
        options -- The POJO options.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_getTaggedObjectsCount(self, ids, options, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.IMetadata._op_getTaggedObjectsCount.begin(self, ((ids, options), _response, _ex, _sent, _ctx))

        """
        Returns a map whose key is a tag id and the value the
        number of Projects, Datasets, and Images linked to that tag.
        Arguments:
        ids -- The collection of ids.
        options -- The POJO options.
        Returns: See above.
        """
        def end_getTaggedObjectsCount(self, _r):
            return _M_omero.api.IMetadata._op_getTaggedObjectsCount.end(self, _r)

        """
        Counts the number of annotation of a given type.
        Arguments:
        annotationType -- The type of annotations to load.
        include -- The collection of name space, one of the constants defined by this class.
        exclude -- The collection of name space, one of the constants defined by this class.
        options -- The POJO options.
        _ctx -- The request context for the invocation.
        Returns: See above.
        """
        def countSpecifiedAnnotations(self, annotationType, include, exclude, options, _ctx=None):
            return _M_omero.api.IMetadata._op_countSpecifiedAnnotations.invoke(self, ((annotationType, include, exclude, options), _ctx))

        """
        Counts the number of annotation of a given type.
        Arguments:
        annotationType -- The type of annotations to load.
        include -- The collection of name space, one of the constants defined by this class.
        exclude -- The collection of name space, one of the constants defined by this class.
        options -- The POJO options.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_countSpecifiedAnnotations(self, annotationType, include, exclude, options, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.IMetadata._op_countSpecifiedAnnotations.begin(self, ((annotationType, include, exclude, options), _response, _ex, _sent, _ctx))

        """
        Counts the number of annotation of a given type.
        Arguments:
        annotationType -- The type of annotations to load.
        include -- The collection of name space, one of the constants defined by this class.
        exclude -- The collection of name space, one of the constants defined by this class.
        options -- The POJO options.
        Returns: See above.
        """
        def end_countSpecifiedAnnotations(self, _r):
            return _M_omero.api.IMetadata._op_countSpecifiedAnnotations.end(self, _r)

        """
        Loads the specified annotations.
        Arguments:
        annotationIds -- The collection of annotation ids.
        _ctx -- The request context for the invocation.
        Returns: See above.
        """
        def loadAnnotation(self, annotationIds, _ctx=None):
            return _M_omero.api.IMetadata._op_loadAnnotation.invoke(self, ((annotationIds, ), _ctx))

        """
        Loads the specified annotations.
        Arguments:
        annotationIds -- The collection of annotation ids.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_loadAnnotation(self, annotationIds, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.IMetadata._op_loadAnnotation.begin(self, ((annotationIds, ), _response, _ex, _sent, _ctx))

        """
        Loads the specified annotations.
        Arguments:
        annotationIds -- The collection of annotation ids.
        Returns: See above.
        """
        def end_loadAnnotation(self, _r):
            return _M_omero.api.IMetadata._op_loadAnnotation.end(self, _r)

        """
        Loads the instrument and its components i.e. detectors,
        objectives, etc.
        Arguments:
        id -- The id of the instrument to load.
        _ctx -- The request context for the invocation.
        Returns: See above
        """
        def loadInstrument(self, id, _ctx=None):
            return _M_omero.api.IMetadata._op_loadInstrument.invoke(self, ((id, ), _ctx))

        """
        Loads the instrument and its components i.e. detectors,
        objectives, etc.
        Arguments:
        id -- The id of the instrument to load.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_loadInstrument(self, id, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.IMetadata._op_loadInstrument.begin(self, ((id, ), _response, _ex, _sent, _ctx))

        """
        Loads the instrument and its components i.e. detectors,
        objectives, etc.
        Arguments:
        id -- The id of the instrument to load.
        Returns: See above
        """
        def end_loadInstrument(self, _r):
            return _M_omero.api.IMetadata._op_loadInstrument.end(self, _r)

        """
        Loads the annotations of a given type used by the specified
        user but not owned by the user.
        Arguments:
        annotationType -- The type of annotations to load.
        userID -- The identifier of the user.
        _ctx -- The request context for the invocation.
        Returns: See above.
        """
        def loadAnnotationsUsedNotOwned(self, annotationType, userID, _ctx=None):
            return _M_omero.api.IMetadata._op_loadAnnotationsUsedNotOwned.invoke(self, ((annotationType, userID), _ctx))

        """
        Loads the annotations of a given type used by the specified
        user but not owned by the user.
        Arguments:
        annotationType -- The type of annotations to load.
        userID -- The identifier of the user.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_loadAnnotationsUsedNotOwned(self, annotationType, userID, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.IMetadata._op_loadAnnotationsUsedNotOwned.begin(self, ((annotationType, userID), _response, _ex, _sent, _ctx))

        """
        Loads the annotations of a given type used by the specified
        user but not owned by the user.
        Arguments:
        annotationType -- The type of annotations to load.
        userID -- The identifier of the user.
        Returns: See above.
        """
        def end_loadAnnotationsUsedNotOwned(self, _r):
            return _M_omero.api.IMetadata._op_loadAnnotationsUsedNotOwned.end(self, _r)

        """
        Counts the number of annotation of a given type used by the
        specified user but not owned by the user.
        Arguments:
        annotationType -- The type of annotations to load.
        userID -- The identifier of the user.
        _ctx -- The request context for the invocation.
        Returns: See above.
        """
        def countAnnotationsUsedNotOwned(self, annotationType, userID, _ctx=None):
            return _M_omero.api.IMetadata._op_countAnnotationsUsedNotOwned.invoke(self, ((annotationType, userID), _ctx))

        """
        Counts the number of annotation of a given type used by the
        specified user but not owned by the user.
        Arguments:
        annotationType -- The type of annotations to load.
        userID -- The identifier of the user.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_countAnnotationsUsedNotOwned(self, annotationType, userID, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.IMetadata._op_countAnnotationsUsedNotOwned.begin(self, ((annotationType, userID), _response, _ex, _sent, _ctx))

        """
        Counts the number of annotation of a given type used by the
        specified user but not owned by the user.
        Arguments:
        annotationType -- The type of annotations to load.
        userID -- The identifier of the user.
        Returns: See above.
        """
        def end_countAnnotationsUsedNotOwned(self, _r):
            return _M_omero.api.IMetadata._op_countAnnotationsUsedNotOwned.end(self, _r)

        """
        Loads the annotations of a given type linked to the
        specified objects. It is possible to filter the annotations
        by including or excluding name spaces set on the
        annotations.
        This method looks for the annotations that have been
        attached to each of the specified objects. It then maps
        each rootNodeId onto the set of annotations
        that were found for that node. If no annotations were found
        for that node, the map will not contain an entry for that
        node. Otherwise it will be a Set containing
        omero.model.Annotation objects.
        The rootNodeType supported are:
        Project, Dataset, Image, Pixels, Screen, Plate,
        PlateAcquisition, Well, Fileset.
        Arguments:
        annotationType -- The type of annotations to load.
        include -- Include the annotations with the specified name spaces.
        exclude -- Exclude the annotations with the specified name spaces.
        rootNodeType -- The type of objects the annotations are linked to.
        rootNodeIds -- The identifiers of the objects.
        options -- The POJO options.
        _ctx -- The request context for the invocation.
        Returns: A collection of found annotations.
        """
        def loadSpecifiedAnnotationsLinkedTo(self, annotationType, include, exclude, rootNodeType, rootNodeIds, options, _ctx=None):
            return _M_omero.api.IMetadata._op_loadSpecifiedAnnotationsLinkedTo.invoke(self, ((annotationType, include, exclude, rootNodeType, rootNodeIds, options), _ctx))

        """
        Loads the annotations of a given type linked to the
        specified objects. It is possible to filter the annotations
        by including or excluding name spaces set on the
        annotations.
        This method looks for the annotations that have been
        attached to each of the specified objects. It then maps
        each rootNodeId onto the set of annotations
        that were found for that node. If no annotations were found
        for that node, the map will not contain an entry for that
        node. Otherwise it will be a Set containing
        omero.model.Annotation objects.
        The rootNodeType supported are:
        Project, Dataset, Image, Pixels, Screen, Plate,
        PlateAcquisition, Well, Fileset.
        Arguments:
        annotationType -- The type of annotations to load.
        include -- Include the annotations with the specified name spaces.
        exclude -- Exclude the annotations with the specified name spaces.
        rootNodeType -- The type of objects the annotations are linked to.
        rootNodeIds -- The identifiers of the objects.
        options -- The POJO options.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_loadSpecifiedAnnotationsLinkedTo(self, annotationType, include, exclude, rootNodeType, rootNodeIds, options, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.IMetadata._op_loadSpecifiedAnnotationsLinkedTo.begin(self, ((annotationType, include, exclude, rootNodeType, rootNodeIds, options), _response, _ex, _sent, _ctx))

        """
        Loads the annotations of a given type linked to the
        specified objects. It is possible to filter the annotations
        by including or excluding name spaces set on the
        annotations.
        This method looks for the annotations that have been
        attached to each of the specified objects. It then maps
        each rootNodeId onto the set of annotations
        that were found for that node. If no annotations were found
        for that node, the map will not contain an entry for that
        node. Otherwise it will be a Set containing
        omero.model.Annotation objects.
        The rootNodeType supported are:
        Project, Dataset, Image, Pixels, Screen, Plate,
        PlateAcquisition, Well, Fileset.
        Arguments:
        annotationType -- The type of annotations to load.
        include -- Include the annotations with the specified name spaces.
        exclude -- Exclude the annotations with the specified name spaces.
        rootNodeType -- The type of objects the annotations are linked to.
        rootNodeIds -- The identifiers of the objects.
        options -- The POJO options.
        Returns: A collection of found annotations.
        """
        def end_loadSpecifiedAnnotationsLinkedTo(self, _r):
            return _M_omero.api.IMetadata._op_loadSpecifiedAnnotationsLinkedTo.end(self, _r)

        """
        Finds the original file IDs for the import logs
        corresponding to the given Image or Fileset IDs.
        Arguments:
        rootType -- the root node type, may be omero.model.Image or omero.model.Fileset
        ids -- the IDs of the entities for which the import log original file IDs are required
        _ctx -- The request context for the invocation.
        Returns: the original file IDs of the import logs
        """
        def loadLogFiles(self, rootType, ids, _ctx=None):
            return _M_omero.api.IMetadata._op_loadLogFiles.invoke(self, ((rootType, ids), _ctx))

        """
        Finds the original file IDs for the import logs
        corresponding to the given Image or Fileset IDs.
        Arguments:
        rootType -- the root node type, may be omero.model.Image or omero.model.Fileset
        ids -- the IDs of the entities for which the import log original file IDs are required
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_loadLogFiles(self, rootType, ids, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.IMetadata._op_loadLogFiles.begin(self, ((rootType, ids), _response, _ex, _sent, _ctx))

        """
        Finds the original file IDs for the import logs
        corresponding to the given Image or Fileset IDs.
        Arguments:
        rootType -- the root node type, may be omero.model.Image or omero.model.Fileset
        ids -- the IDs of the entities for which the import log original file IDs are required
        Returns: the original file IDs of the import logs
        """
        def end_loadLogFiles(self, _r):
            return _M_omero.api.IMetadata._op_loadLogFiles.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.api.IMetadataPrx.ice_checkedCast(proxy, '::omero::api::IMetadata', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.api.IMetadataPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::api::IMetadata'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.api._t_IMetadataPrx = IcePy.defineProxy('::omero::api::IMetadata', IMetadataPrx)

    _M_omero.api._t_IMetadata = IcePy.defineClass('::omero::api::IMetadata', IMetadata, -1, (), True, False, None, (_M_omero.api._t_ServiceInterface,), ())
    IMetadata._ice_type = _M_omero.api._t_IMetadata

    IMetadata._op_loadChannelAcquisitionData = IcePy.Operation('loadChannelAcquisitionData', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, True, None, (), (((), _M_omero.sys._t_LongList, False, 0),), (), ((), _M_omero.api._t_LogicalChannelList, False, 0), (_M_omero._t_ServerError,))
    IMetadata._op_loadAnnotations = IcePy.Operation('loadAnnotations', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, True, None, (), (((), IcePy._t_string, False, 0), ((), _M_omero.sys._t_LongList, False, 0), ((), _M_omero.api._t_StringSet, False, 0), ((), _M_omero.sys._t_LongList, False, 0), ((), _M_omero.sys._t_Parameters, False, 0)), (), ((), _M_omero.api._t_LongIObjectListMap, False, 0), (_M_omero._t_ServerError,))
    IMetadata._op_loadSpecifiedAnnotations = IcePy.Operation('loadSpecifiedAnnotations', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, True, None, (), (((), IcePy._t_string, False, 0), ((), _M_omero.api._t_StringSet, False, 0), ((), _M_omero.api._t_StringSet, False, 0), ((), _M_omero.sys._t_Parameters, False, 0)), (), ((), _M_omero.api._t_AnnotationList, False, 0), (_M_omero._t_ServerError,))
    IMetadata._op_loadTagContent = IcePy.Operation('loadTagContent', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, True, None, (), (((), _M_omero.sys._t_LongList, False, 0), ((), _M_omero.sys._t_Parameters, False, 0)), (), ((), _M_omero.api._t_LongIObjectListMap, False, 0), (_M_omero._t_ServerError,))
    IMetadata._op_loadTagSets = IcePy.Operation('loadTagSets', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, True, None, (), (((), _M_omero.sys._t_Parameters, False, 0),), (), ((), _M_omero.api._t_IObjectList, False, 0), (_M_omero._t_ServerError,))
    IMetadata._op_getTaggedObjectsCount = IcePy.Operation('getTaggedObjectsCount', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, True, None, (), (((), _M_omero.sys._t_LongList, False, 0), ((), _M_omero.sys._t_Parameters, False, 0)), (), ((), _M_omero.sys._t_CountMap, False, 0), (_M_omero._t_ServerError,))
    IMetadata._op_countSpecifiedAnnotations = IcePy.Operation('countSpecifiedAnnotations', Ice.OperationMode.Normal, Ice.OperationMode.Normal, True, None, (), (((), IcePy._t_string, False, 0), ((), _M_omero.api._t_StringSet, False, 0), ((), _M_omero.api._t_StringSet, False, 0), ((), _M_omero.sys._t_Parameters, False, 0)), (), ((), _M_omero._t_RLong, False, 0), (_M_omero._t_ServerError,))
    IMetadata._op_loadAnnotation = IcePy.Operation('loadAnnotation', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, True, None, (), (((), _M_omero.sys._t_LongList, False, 0),), (), ((), _M_omero.api._t_AnnotationList, False, 0), (_M_omero._t_ServerError,))
    IMetadata._op_loadInstrument = IcePy.Operation('loadInstrument', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, True, None, (), (((), IcePy._t_long, False, 0),), (), ((), _M_omero.model._t_Instrument, False, 0), (_M_omero._t_ServerError,))
    IMetadata._op_loadAnnotationsUsedNotOwned = IcePy.Operation('loadAnnotationsUsedNotOwned', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, True, None, (), (((), IcePy._t_string, False, 0), ((), IcePy._t_long, False, 0)), (), ((), _M_omero.api._t_IObjectList, False, 0), (_M_omero._t_ServerError,))
    IMetadata._op_countAnnotationsUsedNotOwned = IcePy.Operation('countAnnotationsUsedNotOwned', Ice.OperationMode.Normal, Ice.OperationMode.Normal, True, None, (), (((), IcePy._t_string, False, 0), ((), IcePy._t_long, False, 0)), (), ((), _M_omero._t_RLong, False, 0), (_M_omero._t_ServerError,))
    IMetadata._op_loadSpecifiedAnnotationsLinkedTo = IcePy.Operation('loadSpecifiedAnnotationsLinkedTo', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, True, None, (), (((), IcePy._t_string, False, 0), ((), _M_omero.api._t_StringSet, False, 0), ((), _M_omero.api._t_StringSet, False, 0), ((), IcePy._t_string, False, 0), ((), _M_omero.sys._t_LongList, False, 0), ((), _M_omero.sys._t_Parameters, False, 0)), (), ((), _M_omero.api._t_LongAnnotationListMap, False, 0), (_M_omero._t_ServerError,))
    IMetadata._op_loadLogFiles = IcePy.Operation('loadLogFiles', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, True, None, (), (((), IcePy._t_string, False, 0), ((), _M_omero.sys._t_LongList, False, 0)), (), ((), _M_omero.api._t_LongIObjectListMap, False, 0), (_M_omero._t_ServerError,))

    _M_omero.api.IMetadata = IMetadata
    del IMetadata

    _M_omero.api.IMetadataPrx = IMetadataPrx
    del IMetadataPrx

# End of module omero.api

__name__ = 'omero'

# End of module omero



#!/usr/bin/env python
# -*- coding: utf-8 -*-

#
# Copyright (C) 2016 University of Dundee & Open Microscopy Environment.
# All rights reserved.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

import omero
import logging
from omero.testlib import ITest
from omero.gateway import BlitzGateway


class ScriptTest(ITest):

    def get_script(self, path):
        script_service = self.root.sf.getScriptService()
        script = _get_script(script_service, path)
        if script is None:
            return -1
        return script.getId().getValue()


def run_script(client, script_id, args, key=None):
    script_service = client.sf.getScriptService()
    proc = script_service.runScript(script_id, args, None)
    try:
        cb = omero.scripts.ProcessCallbackI(client, proc)
        while not cb.block(1000):  # ms.
            pass
        cb.close()
        results = proc.getResults(0)    # ms
    finally:
        proc.close(False)

    if 'stdout' in results:
        orig_file = results['stdout'].getValue()
        v = "Script generated StdOut in file:", orig_file.getId().getValue()
        logging.debug(v)
        assert orig_file.id.val > 0
    if 'stderr' in results:
        orig_file = results['stderr'].getValue()
        v = "Script generated StdErr in file:", orig_file.getId().getValue()
        logging.debug(v)
        assert orig_file.getId().getValue() > 0
    if key and key in results:
        return results[key]


def _get_script(script_service, script_path):
    """ Utility method, return the script or None """
    scripts = script_service.getScripts()     # returns list of OriginalFiles

    # make sure path starts with a slash.
    # ** If you are a Windows client - will need to convert all path separators
    #    to "/" since server stores /path/to/script.py **
    if not script_path.startswith("/"):
        script_path = "/" + script_path

    named_scripts = [
        s for s in scripts if
        s.getPath().getValue() + s.getName().getValue() == script_path]

    if len(named_scripts) == 0:
        return None

    return named_scripts[0]


def points_to_string(points):
    """ Returns legacy format supported by Insight """
    points = ["%s,%s" % (p[0], p[1]) for p in points]
    csv = ", ".join(points)
    return "points[%s] points1[%s] points2[%s]" % (csv, csv, csv)


def check_file_annotation(client, file_annotation,
                          parent_type="Image", is_linked=True,
                          file_name=None):
    """
    Check validity of file annotation. If hasFileAnnotation, check the size,
    name and number of objects linked to the original file.
    """
    assert file_annotation is not None
    orig_file = file_annotation.getValue().getFile()
    assert orig_file.getSize().getValue() > 0
    assert orig_file.getName().getValue() is not None
    id = file_annotation.getValue().getId().getValue()
    assert id > 0

    conn = BlitzGateway(client_obj=client)
    wrapper = conn.getObject("FileAnnotation", id)
    name = None
    if file_name is not None:
        name = wrapper.getFile().getName()

    links = sum(1 for i in wrapper.getParentLinks(parent_type))
    conn.close()

    if is_linked:
        assert links == 1
    else:
        assert links == 0

    if file_name is not None:
        assert name == file_name
